@@ -23,10 +23,15 @@ build=$root/build-win32
 rm -rf $DESTDIR $build
 mkdir -p $build $DESTDIR && cd $build
 
+# Hack for Fedora bug
+if [ "$(id -u)" -eq 0 ]; then
+    sed -i '/^Requires.private: termcap/d'  /usr/x86_64-w64-mingw32/sys-root/mingw/lib/pkgconfig/readline.pc
+fi
+
 # run before using meson
 export WINEPREFIX=$build/.wine
 
-# For logitech bulk controller being disabled (-Dplugin_logitech_bulkcontroller=disabled):
+# For logitech bulk controller being disabled (-Dprotobuf=disabled):
 # See https://bugzilla.redhat.com/show_bug.cgi?id=1991749
 # When fixed need to do the following to enable:
 # 1. need to add mingw64-protobuf mingw64-protobuf-tools to CI build deps
@@ -94,16 +99,21 @@ find $MINGW32BINDIR \
 	-o -name "libnettle-*.dll" \
 	-o -name libp11-kit-0.dll \
 	-o -name libpcre2-8-0.dll \
+	-o -name libpsl-5.dll \
 	-o -name libsqlite3-0.dll \
 	-o -name libssh2-1.dll \
 	-o -name libssl-3-x64.dll \
 	-o -name libssp-0.dll \
+	-o -name libtermcap-0.dll \
+	-o -name libreadline8.dll \
 	-o -name libtasn1-6.dll \
+	-o -name libunistring-2.dll \
 	-o -name libusb-1.0.dll \
 	-o -name libwinpthread-1.dll \
 	-o -name libxml2-2.dll \
 	-o -name libxmlb-2.dll \
 	-o -name libzstd.dll \
+	-o -name wldap32.dll \
 	-o -name zlib1.dll \
 	| wixl-heat \
 	-p $MINGW32BINDIR/ \
@@ -165,6 +175,3 @@ wine msiexec /i "${MSI_FILENAME}"
 ls -R ${WINEPREFIX}/drive_c/Program\ Files/fwupd/
 wine ${WINEPREFIX}/drive_c/Program\ Files/fwupd/bin/fwupdtool.exe get-plugins --json
 wine msiexec /x "${MSI_FILENAME}"
-
-#generate news release
-contrib/ci/generate_news.py $VERSION > $DESTDIR/news.txt
