@@ -10,7 +10,6 @@
 #include <jcat.h>
 
 #include "fwupd-codec.h"
-#include "fwupd-common-private.h"
 #include "fwupd-enums-private.h"
 #include "fwupd-error.h"
 #include "fwupd-remote-private.h"
@@ -519,7 +518,7 @@ fwupd_remote_build_uri(FwupdRemote *self,
 
 	/* sanity check */
 	if (url_noauth == NULL) {
-		g_set_error(error, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO, "no URI set");
+		g_set_error_literal(error, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO, "no URI set");
 		return NULL;
 	}
 
@@ -862,7 +861,7 @@ fwupd_remote_setup(FwupdRemote *self, GError **error)
 		g_autofree gchar *buf = NULL;
 		g_autoptr(GChecksum) checksum_sig = g_checksum_new(G_CHECKSUM_SHA256);
 		if (!g_file_get_contents(priv->filename_cache_sig, &buf, &sz, error)) {
-			g_prefix_error(error, "failed to get signature checksum: ");
+			g_prefix_error_literal(error, "failed to get signature checksum: ");
 			return FALSE;
 		}
 		g_checksum_update(checksum_sig, (guchar *)buf, (gssize)sz);
