@@ -9,7 +9,6 @@
 #include "config.h"
 
 #include "fu-byte-array.h"
-#include "fu-bytes.h"
 #include "fu-common.h"
 #include "fu-efi-common.h"
 #include "fu-efi-filesystem.h"
@@ -56,7 +55,7 @@ fu_efi_volume_validate(FuFirmware *firmware, GInputStream *stream, gsize offset,
 static gboolean
 fu_efi_volume_parse(FuFirmware *firmware,
 		    GInputStream *stream,
-		    FwupdInstallFlags flags,
+		    FuFirmwareParseFlags flags,
 		    GError **error)
 {
 	FuEfiVolume *self = FU_EFI_VOLUME(firmware);
@@ -119,7 +118,7 @@ fu_efi_volume_parse(FuFirmware *firmware,
 	}
 
 	/* verify checksum */
-	if ((flags & FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM) == 0) {
+	if ((flags & FU_FIRMWARE_PARSE_FLAG_IGNORE_CHECKSUM) == 0) {
 		guint16 checksum_verify;
 		g_autoptr(GBytes) blob_hdr = NULL;
 
@@ -169,8 +168,10 @@ fu_efi_volume_parse(FuFirmware *firmware,
 	/* add image */
 	partial_stream =
 	    fu_partial_input_stream_new(stream, hdr_length, fv_length - hdr_length, error);
-	if (partial_stream == NULL)
+	if (partial_stream == NULL) {
+		g_prefix_error_literal(error, "failed to cut EFI volume: ");
 		return FALSE;
+	}
 	fu_firmware_set_id(firmware, guid_str);
 	fu_firmware_set_size(firmware, fv_length);
 
@@ -182,7 +183,7 @@ fu_efi_volume_parse(FuFirmware *firmware,
 		if (!fu_firmware_parse_stream(img,
 					      partial_stream,
 					      0x0,
-					      flags | FWUPD_INSTALL_FLAG_NO_SEARCH,
+					      flags | FU_FIRMWARE_PARSE_FLAG_NO_SEARCH,
 					      error))
 			return FALSE;
 		fu_firmware_add_image(firmware, img);
@@ -252,7 +253,7 @@ fu_efi_volume_write(FuFirmware *firmware, GError **error)
 
 	/* GUID */
 	if (fu_firmware_get_id(firmware) == NULL) {
-		g_set_error(error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL, "no GUID set for EFI FV");
+		g_set_error_literal(error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL, "no GUID set for FV");
 		return NULL;
 	}
 	if (!fwupd_guid_from_string(fu_firmware_get_id(firmware),
@@ -266,13 +267,13 @@ fu_efi_volume_write(FuFirmware *firmware, GError **error)
 	if (img != NULL) {
 		img_blob = fu_firmware_write(img, error);
 		if (img_blob == NULL) {
-			g_prefix_error(error, "no EFI FV child payload: ");
+			g_prefix_error_literal(error, "no EFI FV child payload: ");
 			return NULL;
 		}
 	} else {
 		img_blob = fu_firmware_get_bytes_with_patches(firmware, error);
 		if (img_blob == NULL) {
-			g_prefix_error(error, "no EFI FV payload: ");
+			g_prefix_error_literal(error, "no EFI FV payload: ");
 			return NULL;
 		}
 	}
