@@ -100,10 +100,10 @@ fu_i2c_device_probe(FuDevice *device, GError **error)
 			break;
 		}
 		if (number == G_MAXUINT64) {
-			g_set_error(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_SUPPORTED,
-				    "Could not find i2c bus number in sysfs path");
+			g_set_error_literal(error,
+					    FWUPD_ERROR,
+					    FWUPD_ERROR_NOT_SUPPORTED,
+					    "Could not find i2c bus number in sysfs path");
 			return FALSE;
 		}
 		fu_udev_device_set_number(FU_UDEV_DEVICE(self), number);
@@ -150,14 +150,16 @@ gboolean
 fu_i2c_device_set_address(FuI2cDevice *self, guint8 address, gboolean force, GError **error)
 {
 #ifdef HAVE_I2C_DEV_H
-	if (!fu_udev_device_ioctl(FU_UDEV_DEVICE(self),
-				  force ? I2C_SLAVE_FORCE : I2C_SLAVE,
-				  (guint8 *)(guintptr)address,
-				  sizeof(guintptr),
-				  NULL,
-				  FU_I2C_DEVICE_IOCTL_TIMEOUT,
-				  FU_UDEV_DEVICE_IOCTL_FLAG_NONE,
-				  error)) {
+	g_autoptr(FuIoctl) ioctl = fu_udev_device_ioctl_new(FU_UDEV_DEVICE(self));
+
+	if (!fu_ioctl_execute(ioctl,
+			      force ? I2C_SLAVE_FORCE : I2C_SLAVE,
+			      (guint8 *)(guintptr)address,
+			      sizeof(guintptr),
+			      NULL,
+			      FU_I2C_DEVICE_IOCTL_TIMEOUT,
+			      FU_IOCTL_FLAG_NONE,
+			      error)) {
 		g_prefix_error(error, "failed to set address 0x%02x: ", address);
 		return FALSE;
 	}
@@ -165,10 +167,10 @@ fu_i2c_device_set_address(FuI2cDevice *self, guint8 address, gboolean force, GEr
 	/* success */
 	return TRUE;
 #else
-	g_set_error(error,
-		    FWUPD_ERROR,
-		    FWUPD_ERROR_NOT_SUPPORTED,
-		    "Not supported as <linux/i2c-dev.h> not found");
+	g_set_error_literal(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_NOT_SUPPORTED,
+			    "Not supported as <linux/i2c-dev.h> not found");
 	return FALSE;
 #endif
 }
@@ -211,18 +213,12 @@ fu_i2c_device_read(FuI2cDevice *self, guint8 *buf, gsize bufsz, GError **error)
 	return fu_udev_device_pread(FU_UDEV_DEVICE(self), 0x0, buf, bufsz, error);
 }
 
-static void
-fu_i2c_device_register_flags(FuDevice *device)
-{
-	FU_DEVICE_CLASS(fu_i2c_device_parent_class)->register_flags(device);
-	fu_device_register_private_flag_safe(device, FU_I2C_DEVICE_PRIVATE_FLAG_NO_HWID_GUIDS);
-}
-
 static void
 fu_i2c_device_init(FuI2cDevice *self)
 {
 	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_READ);
 	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_WRITE);
+	fu_device_register_private_flag(FU_DEVICE(self), FU_I2C_DEVICE_PRIVATE_FLAG_NO_HWID_GUIDS);
 }
 
 static void
@@ -230,5 +226,4 @@ fu_i2c_device_class_init(FuI2cDeviceClass *klass)
 {
 	FuDeviceClass *device_class = FU_DEVICE_CLASS(klass);
 	device_class->probe = fu_i2c_device_probe;
-	device_class->register_flags = fu_i2c_device_register_flags;
 }
