@@ -16,6 +16,7 @@
 #include "fu-device-private.h"
 #include "fu-dump.h"
 #include "fu-input-stream.h"
+#include "fu-linear-firmware.h"
 #include "fu-mem.h"
 #include "fu-string.h"
 #include "fu-usb-bos-descriptor-private.h"
@@ -56,20 +57,20 @@ typedef struct {
 	gboolean claimed;
 } FuUsbDeviceInterface;
 
-static void
-fu_usb_device_codec_iface_init(FwupdCodecInterface *iface);
 static gboolean
 fu_usb_device_ensure_interfaces(FuUsbDevice *self, GError **error);
 
-G_DEFINE_TYPE_EXTENDED(FuUsbDevice,
-		       fu_usb_device,
-		       FU_TYPE_UDEV_DEVICE,
-		       0,
-		       G_ADD_PRIVATE(FuUsbDevice)
-			   G_IMPLEMENT_INTERFACE(FWUPD_TYPE_CODEC, fu_usb_device_codec_iface_init));
+G_DEFINE_TYPE_WITH_PRIVATE(FuUsbDevice, fu_usb_device, FU_TYPE_UDEV_DEVICE);
 
 enum { PROP_0, PROP_LIBUSB_DEVICE, PROP_LAST };
 
+enum {
+	QUARK_ADD_INSTANCE_ID_REV,
+	QUARK_LAST,
+};
+
+static guint quarks[QUARK_LAST] = {0};
+
 #define GET_PRIVATE(o) (fu_usb_device_get_instance_private(o))
 
 #define FU_DEVICE_CLAIM_INTERFACE_DELAY 500 /* ms */
@@ -125,53 +126,16 @@ fu_usb_device_libusb_error_to_gerror(gint rc, GError **error)
 static gboolean
 fu_usb_device_libusb_status_to_gerror(gint status, GError **error)
 {
-	gboolean ret = FALSE;
-
-	switch (status) {
-	case LIBUSB_TRANSFER_COMPLETED:
-		ret = TRUE;
-		break;
-	case LIBUSB_TRANSFER_ERROR:
-		g_set_error_literal(error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL, "transfer failed");
-		break;
-	case LIBUSB_TRANSFER_TIMED_OUT:
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_TIMED_OUT,
-				    "transfer timed out");
-		break;
-	case LIBUSB_TRANSFER_CANCELLED:
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOTHING_TO_DO,
-				    "transfer cancelled");
-		break;
-	case LIBUSB_TRANSFER_STALL:
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_SUPPORTED,
-				    "endpoint stalled or request not supported");
-		break;
-	case LIBUSB_TRANSFER_NO_DEVICE:
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_FOUND,
-				    "device was disconnected");
-		break;
-	case LIBUSB_TRANSFER_OVERFLOW:
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_INTERNAL,
-				    "device sent more data than requested");
-		break;
-	default:
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_INTERNAL,
-			    "unknown status [%i]",
-			    status);
-	}
-	return ret;
+	const FuErrorMapEntry entries[] = {
+	    {LIBUSB_TRANSFER_COMPLETED, FWUPD_ERROR_LAST, NULL},
+	    {LIBUSB_TRANSFER_ERROR, FWUPD_ERROR_INTERNAL, "failed"},
+	    {LIBUSB_TRANSFER_TIMED_OUT, FWUPD_ERROR_TIMED_OUT, NULL},
+	    {LIBUSB_TRANSFER_CANCELLED, FWUPD_ERROR_NOTHING_TO_DO, "cancelled"},
+	    {LIBUSB_TRANSFER_STALL, FWUPD_ERROR_NOT_SUPPORTED, "stalled or not supported"},
+	    {LIBUSB_TRANSFER_NO_DEVICE, FWUPD_ERROR_NOT_FOUND, "device was disconnected"},
+	    {LIBUSB_TRANSFER_OVERFLOW, FWUPD_ERROR_INTERNAL, "sent more data than requested"},
+	};
+	return fu_error_map_entry_to_gerror(status, entries, G_N_ELEMENTS(entries), error);
 }
 
 /**
@@ -420,7 +384,7 @@ fu_usb_device_query_hub(FuUsbDevice *self, GError **error)
 					    1000,
 					    NULL,
 					    error)) {
-		g_prefix_error(error, "failed to get USB descriptor: ");
+		g_prefix_error_literal(error, "failed to get USB descriptor: ");
 		return FALSE;
 	}
 	fu_dump_raw(G_LOG_DOMAIN, "HUB_DT", data, sz);
@@ -431,8 +395,8 @@ fu_usb_device_query_hub(FuUsbDevice *self, GError **error)
 		g_string_append_printf(hub, "%02X", data[0x0B]);
 		g_string_append_printf(hub, "%02X", data[0x0A]);
 	} else if (sz >= 9) {
-		guint8 numbytes = fu_common_align_up(data[2] + 1, 0x03) / 8;
-		for (guint i = 0; i < numbytes; i++) {
+		gsize numbytes = fu_common_align_up(data[2] + 1, 0x03) / 8;
+		for (gsize i = 0; i < numbytes; i++) {
 			guint8 tmp = 0x0;
 			if (!fu_memread_uint8_safe(data, sz, 7 + i, &tmp, error))
 				return FALSE;
@@ -564,14 +528,14 @@ fu_usb_device_open(FuDevice *device, GError **error)
 
 	/* open */
 	if (!fu_usb_device_open_internal(self, error)) {
-		g_prefix_error(error, "failed to open device: ");
+		g_prefix_error_literal(error, "failed to open device: ");
 		return FALSE;
 	}
 
 	/* if set */
 	if (priv->configuration >= 0) {
 		if (!fu_usb_device_set_configuration_internal(self, priv->configuration, error)) {
-			g_prefix_error(error, "failed to set configuration: ");
+			g_prefix_error_literal(error, "failed to set configuration: ");
 			return FALSE;
 		}
 	}
@@ -630,7 +594,17 @@ fu_usb_device_get_address(FuUsbDevice *self)
 	return priv->devnum;
 }
 
-static guint8
+/**
+ * fu_usb_device_get_manufacturer_index:
+ * @self: a #FuUsbDevice
+ *
+ * Gets the index for the iManufacturer string descriptor.
+ *
+ * Return value: a string descriptor index.
+ *
+ * Since: 2.0.4
+ **/
+guint8
 fu_usb_device_get_manufacturer_index(FuUsbDevice *self)
 {
 	FuUsbDevicePrivate *priv = GET_PRIVATE(self);
@@ -638,7 +612,17 @@ fu_usb_device_get_manufacturer_index(FuUsbDevice *self)
 	return priv->desc.iManufacturer;
 }
 
-static guint8
+/**
+ * fu_usb_device_get_product_index:
+ * @self: a #FuUsbDevice
+ *
+ * Gets the index for the iProduct string descriptor.
+ *
+ * Return value: a string descriptor index.
+ *
+ * Since: 2.0.4
+ **/
+guint8
 fu_usb_device_get_product_index(FuUsbDevice *self)
 {
 	FuUsbDevicePrivate *priv = GET_PRIVATE(self);
@@ -762,7 +746,7 @@ fu_usb_device_ready(FuDevice *device, GError **error)
 	/* get the interface GUIDs */
 	intfs = fu_usb_device_get_interfaces(self, error);
 	if (intfs == NULL) {
-		g_prefix_error(error, "failed to get interfaces: ");
+		g_prefix_error_literal(error, "failed to get interfaces: ");
 		return FALSE;
 	}
 
@@ -857,18 +841,22 @@ fu_usb_device_probe_bos_descriptor(FuUsbDevice *self, FuUsbBosDescriptor *bos, G
 		return FALSE;
 	ds20 = fu_firmware_new_from_gtypes(stream,
 					   0x0,
-					   FWUPD_INSTALL_FLAG_NONE,
+					   FU_FIRMWARE_PARSE_FLAG_NONE,
 					   error,
 					   FU_TYPE_USB_DEVICE_FW_DS20,
 					   FU_TYPE_USB_DEVICE_MS_DS20,
 					   G_TYPE_INVALID);
 	if (ds20 == NULL) {
-		g_prefix_error(error, "failed to parse: ");
+		g_prefix_error_literal(error, "failed to parse: ");
 		return FALSE;
 	}
 	str = fu_firmware_to_string(ds20);
 	g_debug("DS20: %s", str);
 
+	/* Microsoft descriptors are not useful at the moment */
+	if (FU_IS_USB_DEVICE_MS_DS20(ds20))
+		return TRUE;
+
 	/* set the quirks onto the device */
 	usb_locker = fu_device_locker_new_full(self,
 					       (FuDeviceLockerFunc)fu_usb_device_open,
@@ -877,7 +865,7 @@ fu_usb_device_probe_bos_descriptor(FuUsbDevice *self, FuUsbBosDescriptor *bos, G
 	if (usb_locker == NULL)
 		return FALSE;
 	if (!fu_usb_device_ds20_apply_to_device(FU_USB_DEVICE_DS20(ds20), self, error)) {
-		g_prefix_error(error, "failed to apply DS20 data: ");
+		g_prefix_error_literal(error, "failed to apply DS20 data: ");
 		return FALSE;
 	}
 
@@ -888,8 +876,37 @@ fu_usb_device_probe_bos_descriptor(FuUsbDevice *self, FuUsbBosDescriptor *bos, G
 static GInputStream *
 fu_usb_device_load_descriptor_stream(FuUsbDevice *self, const gchar *basename, GError **error)
 {
+	FuDeviceEvent *event = NULL;
+	g_autofree gchar *event_id = NULL;
 	g_autofree gchar *fn = NULL;
 
+	/* build event key either for load or save */
+	if (fu_device_has_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_EMULATED) ||
+	    fu_context_has_flag(fu_device_get_context(FU_DEVICE(self)),
+				FU_CONTEXT_FLAG_SAVE_EVENTS)) {
+		event_id = g_strdup_printf("LoadDescriptor:basename=%s", basename);
+	}
+
+	/* emulated */
+	if (fu_device_has_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_EMULATED)) {
+		g_autoptr(GBytes) data = NULL;
+
+		/* lots of old emulations don't have this, returning FWUPD_ERROR_NOT_FOUND */
+		event = fu_device_load_event(FU_DEVICE(self), event_id, error);
+		if (event == NULL)
+			return NULL;
+		data = fu_device_event_get_bytes(event, "Data", error);
+		if (data == NULL)
+			return NULL;
+		return g_memory_input_stream_new_from_bytes(data);
+	}
+
+	/* save */
+	if (fu_context_has_flag(fu_device_get_context(FU_DEVICE(self)),
+				FU_CONTEXT_FLAG_SAVE_EVENTS)) {
+		event = fu_device_save_event(FU_DEVICE(self), event_id);
+	}
+
 	/* kernel weirdness -- fseek(fd, 0L, SEEK_END) always gives us 0x10011 */
 	fn = g_build_filename(fu_device_get_backend_id(FU_DEVICE(self)), basename, NULL);
 	if (!g_file_test(fn, G_FILE_TEST_EXISTS)) {
@@ -900,6 +917,16 @@ fu_usb_device_load_descriptor_stream(FuUsbDevice *self, const gchar *basename, G
 			    fn);
 		return NULL;
 	}
+
+	/* save */
+	if (event != NULL) {
+		g_autoptr(GBytes) data = fu_bytes_get_contents(fn, error);
+		if (data == NULL)
+			return NULL;
+		fu_device_event_set_bytes(event, "Data", data);
+	}
+
+	/* success */
 	return fu_input_stream_from_path(fn, error);
 }
 
@@ -907,30 +934,32 @@ static gboolean
 fu_usb_device_parse_bos_descriptor(FuUsbDevice *self, GInputStream *stream, GError **error)
 {
 	FuUsbDevicePrivate *priv = GET_PRIVATE(self);
-	gsize offset = 0;
-	gsize streamsz = 0;
+	g_autoptr(FuFirmware) firmware = fu_linear_firmware_new(FU_TYPE_USB_BOS_DESCRIPTOR);
+	g_autoptr(GError) error_local = NULL;
+	g_autoptr(GPtrArray) imgs = NULL;
 
-	if (!fu_input_stream_size(stream, &streamsz, error))
-		return FALSE;
-	while (offset < streamsz) {
-		g_autoptr(GError) error_local = NULL;
-		g_autoptr(FuUsbBosDescriptor) bos_descriptor =
-		    g_object_new(FU_TYPE_USB_BOS_DESCRIPTOR, NULL);
-		if (!fu_firmware_parse_stream(FU_FIRMWARE(bos_descriptor),
-					      stream,
-					      offset,
-					      FWUPD_INSTALL_FLAG_NONE,
-					      &error_local)) {
-			if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE))
-				break;
-			if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_INVALID_DATA))
-				break;
+	if (!fu_firmware_parse_stream(firmware,
+				      stream,
+				      0x0,
+				      FU_FIRMWARE_PARSE_FLAG_NONE,
+				      &error_local)) {
+		if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE) ||
+		    g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_INVALID_DATA)) {
+			g_debug("ignoring: %s", error_local->message);
+		} else {
 			g_propagate_error(error, g_steal_pointer(&error_local));
 			return FALSE;
 		}
-		offset += fu_firmware_get_size(FU_FIRMWARE(bos_descriptor));
-		g_ptr_array_add(priv->bos_descriptors, g_steal_pointer(&bos_descriptor));
 	}
+
+	/* copy from container */
+	imgs = fu_firmware_get_images(firmware);
+	for (guint i = 0; i < imgs->len; i++) {
+		FuFirmware *img = g_ptr_array_index(imgs, i);
+		g_ptr_array_add(priv->bos_descriptors, g_object_ref(img));
+	}
+
+	/* success */
 	return TRUE;
 }
 
@@ -942,8 +971,6 @@ fu_usb_device_ensure_bos_descriptors(FuUsbDevice *self, GError **error)
 	/* already set */
 	if (priv->bos_descriptors_valid)
 		return TRUE;
-	if (fu_device_has_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_EMULATED))
-		return TRUE;
 
 	/* libusb or kernel */
 	if (priv->usb_device != NULL) {
@@ -986,14 +1013,15 @@ fu_usb_device_ensure_bos_descriptors(FuUsbDevice *self, GError **error)
 		}
 		libusb_free_bos_descriptor(bos);
 	} else {
-		g_autoptr(GInputStream) stream = NULL;
 		g_autoptr(GError) error_local = NULL;
+		g_autoptr(GInputStream) stream = NULL;
 
 		/* this is optional */
 		stream =
 		    fu_usb_device_load_descriptor_stream(self, "bos_descriptors", &error_local);
 		if (stream == NULL) {
-			if (!g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED)) {
+			if (!g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED) &&
+			    !g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND)) {
 				g_propagate_error(error, g_steal_pointer(&error_local));
 				return FALSE;
 			}
@@ -1026,7 +1054,7 @@ fu_usb_device_probe_bos_descriptors(FuUsbDevice *self, GError **error)
 			return TRUE;
 		}
 		g_propagate_error(error, g_steal_pointer(&error_local));
-		fu_error_convert(error);
+		fwupd_error_convert(error);
 		return FALSE;
 	}
 	for (guint i = 0; i < priv->bos_descriptors->len; i++) {
@@ -1161,7 +1189,7 @@ fu_usb_device_probe(FuDevice *device, GError **error)
 					 "VID",
 					 "PID",
 					 NULL);
-	if (fu_device_has_private_flag(device, FU_DEVICE_PRIVATE_FLAG_ADD_INSTANCE_ID_REV)) {
+	if (fu_device_has_private_flag_quark(device, quarks[QUARK_ADD_INSTANCE_ID_REV])) {
 		fu_device_build_instance_id_full(device,
 						 FU_DEVICE_INSTANCE_FLAG_GENERIC |
 						     FU_DEVICE_INSTANCE_FLAG_VISIBLE |
@@ -1177,7 +1205,7 @@ fu_usb_device_probe(FuDevice *device, GError **error)
 	/* add the interface GUIDs */
 	intfs = fu_usb_device_get_interfaces(self, error);
 	if (intfs == NULL) {
-		g_prefix_error(error, "failed to get interfaces: ");
+		g_prefix_error_literal(error, "failed to get interfaces: ");
 		return FALSE;
 	}
 	for (guint i = 0; i < intfs->len; i++) {
@@ -1770,7 +1798,7 @@ fu_usb_device_parse_descriptor(FuUsbDevice *self, GInputStream *stream, GError *
 			if (!fu_firmware_parse_stream(FU_FIRMWARE(cfg_descriptor),
 						      stream,
 						      offset,
-						      FWUPD_INSTALL_FLAG_NONE,
+						      FU_FIRMWARE_PARSE_FLAG_NONE,
 						      error))
 				return FALSE;
 			g_ptr_array_add(priv->cfg_descriptors, g_steal_pointer(&cfg_descriptor));
@@ -1779,17 +1807,37 @@ fu_usb_device_parse_descriptor(FuUsbDevice *self, GInputStream *stream, GError *
 			if (!fu_firmware_parse_stream(FU_FIRMWARE(iface),
 						      stream,
 						      offset,
-						      FWUPD_INSTALL_FLAG_NONE,
+						      FU_FIRMWARE_PARSE_FLAG_NONE,
 						      error))
 				return FALSE;
 			fu_usb_device_add_interface_internal(self, iface);
+
+			/* the next descriptor is the custom one, so just add as a child */
+			if (fu_usb_interface_get_class(iface) ==
+			    FU_USB_CLASS_APPLICATION_SPECIFIC) {
+				g_autoptr(FuUsbDescriptor) img =
+				    g_object_new(FU_TYPE_USB_DESCRIPTOR, NULL);
+				if (!fu_firmware_parse_stream(
+					FU_FIRMWARE(img),
+					stream,
+					offset + fu_usb_base_hdr_get_length(st_base),
+					FU_FIRMWARE_PARSE_FLAG_CACHE_BLOB,
+					error))
+					return FALSE;
+				if (!fu_firmware_add_image_full(FU_FIRMWARE(iface),
+								FU_FIRMWARE(img),
+								error))
+					return FALSE;
+				offset += fu_firmware_get_size(FU_FIRMWARE(img));
+			}
+
 			g_set_object(&iface_last, iface);
 		} else if (descriptor_kind == FU_USB_DESCRIPTOR_KIND_ENDPOINT) {
 			g_autoptr(FuUsbEndpoint) ep = g_object_new(FU_TYPE_USB_ENDPOINT, NULL);
 			if (!fu_firmware_parse_stream(FU_FIRMWARE(ep),
 						      stream,
 						      offset,
-						      FWUPD_INSTALL_FLAG_NONE,
+						      FU_FIRMWARE_PARSE_FLAG_NONE,
 						      error))
 				return FALSE;
 			if (iface_last == NULL) {
@@ -1803,7 +1851,7 @@ fu_usb_device_parse_descriptor(FuUsbDevice *self, GInputStream *stream, GError *
 			if (!fu_firmware_parse_stream(FU_FIRMWARE(hid_descriptor),
 						      stream,
 						      offset,
-						      FWUPD_INSTALL_FLAG_NONE,
+						      FU_FIRMWARE_PARSE_FLAG_NONE,
 						      error))
 				return FALSE;
 			if (iface_last == NULL) {
@@ -1837,8 +1885,6 @@ fu_usb_device_ensure_interfaces(FuUsbDevice *self, GError **error)
 	/* sanity check */
 	if (priv->interfaces_valid)
 		return TRUE;
-	if (fu_device_has_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_EMULATED))
-		return TRUE;
 
 	/* libusb or kernel */
 	if (priv->usb_device != NULL) {
@@ -1858,12 +1904,19 @@ fu_usb_device_ensure_interfaces(FuUsbDevice *self, GError **error)
 		}
 		libusb_free_config_descriptor(config);
 	} else {
+		g_autoptr(GError) error_local = NULL;
 		g_autoptr(GInputStream) stream = NULL;
-		stream = fu_usb_device_load_descriptor_stream(self, "descriptors", error);
-		if (stream == NULL)
-			return FALSE;
-		if (!fu_usb_device_parse_descriptor(self, stream, error))
-			return FALSE;
+
+		stream = fu_usb_device_load_descriptor_stream(self, "descriptors", &error_local);
+		if (stream == NULL) {
+			if (!g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND)) {
+				g_propagate_error(error, g_steal_pointer(&error_local));
+				return FALSE;
+			}
+		} else {
+			if (!fu_usb_device_parse_descriptor(self, stream, error))
+				return FALSE;
+		}
 	}
 
 	priv->interfaces_valid = TRUE;
@@ -1905,7 +1958,7 @@ fu_usb_device_get_interfaces(FuUsbDevice *self, GError **error)
  * Gets the first interface that matches the vendor class interface descriptor.
  * If you want to find all the interfaces that match (there may be other
  * 'alternate' interfaces you have to use fu_usb_device_get_interfaces() and
- * check each one manally.
+ * check each one manually.
  *
  * Return value: (transfer full): a #FuUsbInterface or %NULL for not found
  *
@@ -2594,7 +2647,7 @@ fu_usb_device_ensure_hid_descriptor(FuUsbDevice *self,
 					    5000,
 					    NULL,
 					    error)) {
-		g_prefix_error(error, "failed to get HID report descriptor: ");
+		g_prefix_error_literal(error, "failed to get HID report descriptor: ");
 		return FALSE;
 	}
 	fu_dump_raw(G_LOG_DOMAIN, "HidDescriptor", buf, bufsz);
@@ -2631,8 +2684,15 @@ fu_usb_device_ensure_hid_descriptors(FuUsbDevice *self, GError **error)
 		return FALSE;
 	for (guint i = 0; i < priv->hid_descriptors->len; i++) {
 		FuUsbHidDescriptor *hid_descriptor = g_ptr_array_index(priv->hid_descriptors, i);
-		if (!fu_usb_device_ensure_hid_descriptor(self, hid_descriptor, error))
-			return FALSE;
+		g_autoptr(GError) error_local = NULL;
+		if (!fu_usb_device_ensure_hid_descriptor(self, hid_descriptor, &error_local)) {
+			if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_READ)) {
+				g_debug("ignoring: %s", error_local->message);
+			} else {
+				g_propagate_error(error, g_steal_pointer(&error_local));
+				return FALSE;
+			}
+		}
 	}
 	return TRUE;
 }
@@ -2674,42 +2734,16 @@ fu_usb_device_get_hid_descriptors(FuUsbDevice *self, GError **error)
 }
 
 static gboolean
-fu_usb_device_from_json(FwupdCodec *codec, JsonNode *json_node, GError **error)
+fu_usb_device_from_json(FuDevice *device, JsonObject *json_object, GError **error)
 {
-	FuUsbDevice *self = FU_USB_DEVICE(codec);
+	FuUsbDevice *self = FU_USB_DEVICE(device);
 	FuUsbDevicePrivate *priv = GET_PRIVATE(self);
 	const gchar *tmp;
-	JsonObject *json_object;
-
-	/* sanity check */
-	if (!JSON_NODE_HOLDS_OBJECT(json_node)) {
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_INVALID_DATA,
-				    "not JSON object");
-		return FALSE;
-	}
-	json_object = json_node_get_object(json_node);
 
 	/* optional properties */
 	tmp = json_object_get_string_member_with_default(json_object, "PlatformId", NULL);
 	if (tmp != NULL)
 		fu_device_set_physical_id(FU_DEVICE(self), tmp);
-#if GLIB_CHECK_VERSION(2, 80, 0)
-	tmp = json_object_get_string_member_with_default(json_object, "Created", NULL);
-	if (tmp != NULL) {
-		g_autoptr(GDateTime) created_new = g_date_time_new_from_iso8601(tmp, NULL);
-		if (created_new == NULL) {
-			g_set_error(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_INVALID_DATA,
-				    "cannot parse ISO8601 date: %s",
-				    tmp);
-			return FALSE;
-		}
-		fu_device_set_created_usec(FU_DEVICE(self), g_date_time_to_unix_usec(created_new));
-	}
-#endif
 	fu_device_set_vid(FU_DEVICE(self),
 			  json_object_get_int_member_with_default(json_object, "IdVendor", 0x0));
 	fu_device_set_pid(FU_DEVICE(self),
@@ -2801,11 +2835,11 @@ fu_usb_device_from_json(FwupdCodec *codec, JsonNode *json_node, GError **error)
 }
 
 static void
-fu_usb_device_add_json(FwupdCodec *codec, JsonBuilder *builder, FwupdCodecFlags flags)
+fu_usb_device_add_json(FuDevice *device, JsonBuilder *builder, FwupdCodecFlags flags)
 {
-	FuUsbDevice *self = FU_USB_DEVICE(codec);
+	FuUsbDevice *self = FU_USB_DEVICE(device);
 	FuUsbDevicePrivate *priv = GET_PRIVATE(self);
-	GPtrArray *events = fu_device_get_events(FU_DEVICE(self));
+	GPtrArray *events = fu_device_get_events(device);
 	g_autoptr(GPtrArray) interfaces = NULL;
 	g_autoptr(GError) error_bos = NULL;
 	g_autoptr(GError) error_hid = NULL;
@@ -2814,14 +2848,17 @@ fu_usb_device_add_json(FwupdCodec *codec, JsonBuilder *builder, FwupdCodecFlags
 	/* optional properties */
 	fwupd_codec_json_append(builder, "GType", "FuUsbDevice");
 	fwupd_codec_json_append(builder, "PlatformId", fu_device_get_physical_id(FU_DEVICE(self)));
-#if GLIB_CHECK_VERSION(2, 80, 0)
 	if (fu_device_get_created_usec(FU_DEVICE(self)) != 0) {
+#if GLIB_CHECK_VERSION(2, 80, 0)
 		g_autoptr(GDateTime) dt =
 		    g_date_time_new_from_unix_utc_usec(fu_device_get_created_usec(FU_DEVICE(self)));
+#else
+		g_autoptr(GDateTime) dt = g_date_time_new_from_unix_utc(
+		    fu_device_get_created_usec(FU_DEVICE(self)) / G_USEC_PER_SEC);
+#endif
 		g_autofree gchar *str = g_date_time_format_iso8601(dt);
 		fwupd_codec_json_append(builder, "Created", str);
 	}
-#endif
 	if (fu_device_get_vid(FU_DEVICE(self)) != 0) {
 		fwupd_codec_json_append_int(builder,
 					    "IdVendor",
@@ -2916,20 +2953,16 @@ fu_usb_device_add_json(FwupdCodec *codec, JsonBuilder *builder, FwupdCodecFlags
 		for (guint i = 0; i < events->len; i++) {
 			FuDeviceEvent *event = g_ptr_array_index(events, i);
 			json_builder_begin_object(builder);
-			fwupd_codec_to_json(FWUPD_CODEC(event), builder, flags);
+			fwupd_codec_to_json(FWUPD_CODEC(event),
+					    builder,
+					    events->len > 1000 ? flags | FWUPD_CODEC_FLAG_COMPRESSED
+							       : flags);
 			json_builder_end_object(builder);
 		}
 		json_builder_end_array(builder);
 	}
 }
 
-static void
-fu_usb_device_codec_iface_init(FwupdCodecInterface *iface)
-{
-	iface->add_json = fu_usb_device_add_json;
-	iface->from_json = fu_usb_device_from_json;
-}
-
 /**
  * fu_usb_device_new: (skip):
  * @ctx: (nullable): a #FuContext
@@ -3023,6 +3056,12 @@ fu_usb_device_class_init(FuUsbDeviceClass *klass)
 	device_class->to_string = fu_usb_device_to_string;
 	device_class->incorporate = fu_usb_device_incorporate;
 	device_class->convert_version = fu_usb_device_convert_version;
+	device_class->from_json = fu_usb_device_from_json;
+	device_class->add_json = fu_usb_device_add_json;
+
+	/* used as device flags */
+	quarks[QUARK_ADD_INSTANCE_ID_REV] =
+	    g_quark_from_static_string(FU_DEVICE_PRIVATE_FLAG_ADD_INSTANCE_ID_REV);
 
 	/**
 	 * FuUsbDevice:libusb-device:
