@@ -14,9 +14,7 @@
 #include "fu-coswid-firmware.h"
 #include "fu-input-stream.h"
 #include "fu-lzma-common.h"
-#include "fu-mem.h"
 #include "fu-partial-input-stream.h"
-#include "fu-string.h"
 #include "fu-uswid-firmware.h"
 #include "fu-uswid-struct.h"
 
@@ -61,7 +59,7 @@ fu_uswid_firmware_validate(FuFirmware *firmware, GInputStream *stream, gsize off
 static gboolean
 fu_uswid_firmware_parse(FuFirmware *firmware,
 			GInputStream *stream,
-			FwupdInstallFlags flags,
+			FuFirmwareParseFlags flags,
 			GError **error)
 {
 	FuUswidFirmware *self = FU_USWID_FIRMWARE(firmware);
@@ -120,11 +118,14 @@ fu_uswid_firmware_parse(FuFirmware *firmware,
 		g_autoptr(GInputStream) istream2 = NULL;
 		conv = G_CONVERTER(g_zlib_decompressor_new(G_ZLIB_COMPRESSOR_FORMAT_ZLIB));
 		istream1 = fu_partial_input_stream_new(stream, hdrsz, payloadsz, error);
-		if (istream1 == NULL)
+		if (istream1 == NULL) {
+			g_prefix_error_literal(error, "failed to cut uSWID payload: ");
 			return FALSE;
+		}
 		if (!g_seekable_seek(G_SEEKABLE(istream1), 0, G_SEEK_SET, NULL, error))
 			return FALSE;
 		istream2 = g_converter_input_stream_new(istream1, conv);
+		g_filter_input_stream_set_close_base_stream(G_FILTER_INPUT_STREAM(istream2), FALSE);
 		payload = fu_input_stream_read_bytes(istream2, 0, G_MAXSIZE, NULL, error);
 		if (payload == NULL)
 			return FALSE;
@@ -133,7 +134,7 @@ fu_uswid_firmware_parse(FuFirmware *firmware,
 		payload_tmp = fu_input_stream_read_bytes(stream, hdrsz, payloadsz, NULL, error);
 		if (payload_tmp == NULL)
 			return FALSE;
-		payload = fu_lzma_decompress_bytes(payload_tmp, error);
+		payload = fu_lzma_decompress_bytes(payload_tmp, 16 * 1024 * 1024, error);
 		if (payload == NULL)
 			return FALSE;
 	} else if (priv->compression == FU_USWID_PAYLOAD_COMPRESSION_NONE) {
@@ -162,7 +163,7 @@ fu_uswid_firmware_parse(FuFirmware *firmware,
 		if (!fu_firmware_parse_bytes(firmware_coswid,
 					     fw2,
 					     0x0,
-					     flags | FWUPD_INSTALL_FLAG_NO_SEARCH,
+					     flags | FU_FIRMWARE_PARSE_FLAG_NO_SEARCH,
 					     error))
 			return FALSE;
 		if (!fu_firmware_add_image_full(firmware, firmware_coswid, error))
