@@ -13,7 +13,7 @@
 #include "fu-ccgx-dmc-struct.h"
 
 struct _FuCcgxDmcFirmware {
-	FuFirmwareClass parent_instance;
+	FuFirmware parent_instance;
 	GPtrArray *image_records;
 	GBytes *fwct_blob;
 	GBytes *custom_meta_blob;
@@ -90,7 +90,7 @@ fu_ccgx_dmc_firmware_parse_segment(FuFirmware *firmware,
 				   GInputStream *stream,
 				   FuCcgxDmcFirmwareRecord *img_rcd,
 				   gsize *seg_off,
-				   FwupdInstallFlags flags,
+				   FuFirmwareParseFlags flags,
 				   GError **error)
 {
 	FuCcgxDmcFirmware *self = FU_CCGX_DMC_FIRMWARE(firmware);
@@ -157,7 +157,7 @@ fu_ccgx_dmc_firmware_parse_segment(FuFirmware *firmware,
 	}
 
 	/* check checksum */
-	if ((flags & FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM) == 0) {
+	if ((flags & FU_FIRMWARE_PARSE_FLAG_IGNORE_CHECKSUM) == 0) {
 		guint8 csumbuf[DMC_HASH_SIZE] = {0x0};
 		gsize csumbufsz = sizeof(csumbuf);
 		g_checksum_get_digest(csum, csumbuf, &csumbufsz);
@@ -178,7 +178,7 @@ static gboolean
 fu_ccgx_dmc_firmware_parse_image(FuFirmware *firmware,
 				 guint8 image_count,
 				 GInputStream *stream,
-				 FwupdInstallFlags flags,
+				 FuFirmwareParseFlags flags,
 				 GError **error)
 {
 	FuCcgxDmcFirmware *self = FU_CCGX_DMC_FIRMWARE(firmware);
@@ -188,8 +188,6 @@ fu_ccgx_dmc_firmware_parse_image(FuFirmware *firmware,
 
 	/* set initial segment info offset */
 	for (guint32 i = 0; i < image_count; i++) {
-		gsize img_digestsz = 0;
-		const guint8 *img_digest;
 		g_autoptr(FuCcgxDmcFirmwareRecord) img_rcd = NULL;
 		g_autoptr(GByteArray) st_img = NULL;
 
@@ -210,37 +208,37 @@ fu_ccgx_dmc_firmware_parse_image(FuFirmware *firmware,
 		img_rcd->img_offset = fu_struct_ccgx_dmc_fwct_image_info_get_img_offset(st_img);
 		img_rcd->num_img_segments =
 		    fu_struct_ccgx_dmc_fwct_image_info_get_num_img_segments(st_img);
-		if (img_rcd->num_img_segments == 0) {
-			g_set_error(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_SUPPORTED,
-				    "invalid segment number = %d",
-				    img_rcd->num_img_segments);
-			return FALSE;
+
+		/* segments are optional */
+		if (img_rcd->num_img_segments > 0) {
+			gsize img_digestsz = 0;
+			const guint8 *img_digest;
+
+			img_digest =
+			    fu_struct_ccgx_dmc_fwct_image_info_get_img_digest(st_img,
+									      &img_digestsz);
+			if (!fu_memcpy_safe((guint8 *)&img_rcd->img_digest,
+					    sizeof(img_rcd->img_digest),
+					    0x0, /* dst */
+					    img_digest,
+					    img_digestsz,
+					    0, /* src */
+					    img_digestsz,
+					    error))
+				return FALSE;
+
+			/* parse segment */
+			if (!fu_ccgx_dmc_firmware_parse_segment(firmware,
+								stream,
+								img_rcd,
+								&seg_off,
+								flags,
+								error))
+				return FALSE;
+
+			/* add image record to image record array */
+			g_ptr_array_add(self->image_records, g_steal_pointer(&img_rcd));
 		}
-		img_digest =
-		    fu_struct_ccgx_dmc_fwct_image_info_get_img_digest(st_img, &img_digestsz);
-		if (!fu_memcpy_safe((guint8 *)&img_rcd->img_digest,
-				    sizeof(img_rcd->img_digest),
-				    0x0, /* dst */
-				    img_digest,
-				    img_digestsz,
-				    0, /* src */
-				    img_digestsz,
-				    error))
-			return FALSE;
-
-		/* parse segment */
-		if (!fu_ccgx_dmc_firmware_parse_segment(firmware,
-							stream,
-							img_rcd,
-							&seg_off,
-							flags,
-							error))
-			return FALSE;
-
-		/* add image record to image record array */
-		g_ptr_array_add(self->image_records, g_steal_pointer(&img_rcd));
 
 		/* increment image offset */
 		img_off += FU_STRUCT_CCGX_DMC_FWCT_IMAGE_INFO_SIZE;
@@ -261,7 +259,7 @@ fu_ccgx_dmc_firmware_validate(FuFirmware *firmware,
 static gboolean
 fu_ccgx_dmc_firmware_parse(FuFirmware *firmware,
 			   GInputStream *stream,
-			   FwupdInstallFlags flags,
+			   FuFirmwareParseFlags flags,
 			   GError **error)
 {
 	FuCcgxDmcFirmware *self = FU_CCGX_DMC_FIRMWARE(firmware);
@@ -301,7 +299,7 @@ fu_ccgx_dmc_firmware_parse(FuFirmware *firmware,
 
 	/* create custom meta binary */
 	if (!fu_input_stream_read_u16(stream, hdr_size, &mdbufsz, G_LITTLE_ENDIAN, error)) {
-		g_prefix_error(error, "failed to read metadata size: ");
+		g_prefix_error_literal(error, "failed to read metadata size: ");
 		return FALSE;
 	}
 	if (mdbufsz > 0) {
@@ -401,7 +399,8 @@ fu_ccgx_dmc_firmware_write(FuFirmware *firmware, GError **error)
 						       FU_CHUNK_ADDR_OFFSET_NONE,
 						       FU_CHUNK_PAGESZ_NONE,
 						       64);
-		img_padded = fu_bytes_pad(img_bytes, MAX(fu_chunk_array_length(chunks), 1) * 64);
+		img_padded =
+		    fu_bytes_pad(img_bytes, MAX(fu_chunk_array_length(chunks), 1) * 64, 0xFF);
 		fu_byte_array_append_bytes(buf, img_padded);
 		g_checksum_update(csum,
 				  (const guchar *)g_bytes_get_data(img_padded, NULL),
