@@ -84,7 +84,7 @@ static FuFirmware *
 fu_cfu_module_prepare_firmware(FuDevice *device,
 			       GInputStream *stream,
 			       FuProgress *progress,
-			       FwupdInstallFlags flags,
+			       FuFirmwareParseFlags flags,
 			       GError **error)
 {
 	g_autoptr(FuFirmware) firmware = fu_firmware_new();
@@ -145,10 +145,10 @@ fu_cfu_module_write_firmware(FuDevice *device,
 	/* process by the parent */
 	proxy = fu_device_get_proxy(device);
 	if (proxy == NULL) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOT_SUPPORTED,
-			    "no proxy device assigned");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "no proxy device assigned");
 		return FALSE;
 	}
 	device_class = FU_DEVICE_GET_CLASS(proxy);
@@ -160,6 +160,7 @@ fu_cfu_module_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 96, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
