@@ -131,18 +131,24 @@ fu_flashrom_plugin_device_set_bios_info(FuPlugin *plugin, FuDevice *device, GErr
 		if (!fu_memread_uint8_safe(buf, bufsz, 0x9, &bios_sz, NULL))
 			return FALSE;
 
+		/* need to read extended ROM size */
 		if (bios_sz == 0xff) {
-			/* Need to read extended ROM size */
-			if (!fu_memread_uint8_safe(buf, bufsz, 0x18, &bios_sz, NULL))
-				return FALSE;
+			guint16 bios_sz_ext = 0x0;
 
 			/* Bits 15-14 scale, 13-0 size
 			 *  00 scale -> MiB
 			 *  01 scale -> GiB
 			 *  others reserved
 			 */
-			firmware_size = (bios_sz & 0x3ff) * (1024 * 1024);
-			if (bios_sz & 0xc000)
+			if (!fu_memread_uint16_safe(buf,
+						    bufsz,
+						    0x18,
+						    &bios_sz_ext,
+						    G_LITTLE_ENDIAN,
+						    error))
+				return FALSE;
+			firmware_size = (bios_sz_ext & 0x3ff) * (1024 * 1024);
+			if (bios_sz_ext & 0xc000)
 				firmware_size *= 1024;
 		} else {
 			firmware_size = (bios_sz + 1) * 64 * 1024;
@@ -285,12 +291,76 @@ fu_flashrom_plugin_find_guid(FuPlugin *plugin, GError **error)
 	return NULL;
 }
 
+typedef char *flashrom_data;
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(flashrom_data, flashrom_data_free)
+
+static gboolean
+fu_flashrom_plugin_probe(FuFlashromPlugin *self, GError **error)
+{
+	gint rc;
+#ifdef HAVE_FLASHROM_FLASH_PROBE_V2
+	g_autoptr(flashrom_data) all_matched_names = NULL;
+
+	rc = flashrom_flash_probe_v2(self->flashctx,
+				     (const char ***const)&all_matched_names,
+				     self->flashprog,
+				     NULL);
+	if (rc == -1) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "flash probe failed: unknown error");
+		return FALSE;
+	}
+	if (rc == 0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "flash probe failed: no chips matched");
+		return FALSE;
+	}
+	if (rc > 1) {
+		g_autofree gchar *names = g_strjoinv(",", all_matched_names);
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_NOT_SUPPORTED,
+			    "flash probe failed: multiple chips were found: %s",
+			    names);
+		return FALSE;
+	}
+#else
+	rc = flashrom_flash_probe(&self->flashctx, self->flashprog, NULL);
+	if (rc == 3) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "flash probe failed: multiple chips were found");
+		return FALSE;
+	}
+	if (rc == 2) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "flash probe failed: no chip was found");
+		return FALSE;
+	}
+	if (rc != 0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "flash probe failed: unknown error");
+		return FALSE;
+	}
+#endif
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_flashrom_plugin_startup(FuPlugin *plugin, FuProgress *progress, GError **error)
 {
 	const gchar *flashrom_args;
 	const gchar *flashrom_prog;
-	gint rc;
 	const gchar *guid;
 	FuContext *ctx = fu_plugin_get_context(plugin);
 	FuFlashromPlugin *self = FU_FLASHROM_PLUGIN(plugin);
@@ -335,29 +405,8 @@ fu_flashrom_plugin_startup(FuPlugin *plugin, FuProgress *progress, GError **erro
 				    "programmer initialization failed");
 		return FALSE;
 	}
-
-	rc = flashrom_flash_probe(&self->flashctx, self->flashprog, NULL);
-	if (rc == 3) {
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_SUPPORTED,
-				    "flash probe failed: multiple chips were found");
+	if (!fu_flashrom_plugin_probe(self, error))
 		return FALSE;
-	}
-	if (rc == 2) {
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_SUPPORTED,
-				    "flash probe failed: no chip was found");
-		return FALSE;
-	}
-	if (rc != 0) {
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_SUPPORTED,
-				    "flash probe failed: unknown error");
-		return FALSE;
-	}
 	fu_progress_step_done(progress);
 
 	return TRUE;
@@ -373,7 +422,9 @@ static void
 fu_flashrom_plugin_constructed(GObject *obj)
 {
 	FuPlugin *plugin = FU_PLUGIN(obj);
+	FuContext *ctx = fu_plugin_get_context(plugin);
 
+	fu_context_add_quirk_key(ctx, "FlashromFmapRegions");
 	(void)fu_plugin_alloc_data(plugin, sizeof(FuFlashromPlugin));
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_METADATA_SOURCE, "linux_lockdown");
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_CONFLICTS, "coreboot"); /* obsoleted */
