@@ -48,22 +48,22 @@ G_DEFINE_TYPE_WITH_PRIVATE(FuLogitechHidppDevice, fu_logitech_hidpp_device, FU_T
 #define GET_PRIVATE(o) (fu_logitech_hidpp_device_get_instance_private(o))
 
 typedef enum {
-	FU_HIDPP_DEVICE_KIND_KEYBOARD,
-	FU_HIDPP_DEVICE_KIND_REMOTE_CONTROL,
-	FU_HIDPP_DEVICE_KIND_NUMPAD,
-	FU_HIDPP_DEVICE_KIND_MOUSE,
-	FU_HIDPP_DEVICE_KIND_TOUCHPAD,
-	FU_HIDPP_DEVICE_KIND_TRACKBALL,
-	FU_HIDPP_DEVICE_KIND_PRESENTER,
-	FU_HIDPP_DEVICE_KIND_RECEIVER,
-	FU_HIDPP_DEVICE_KIND_LAST
+	FU_LOGITECH_HIDPP_DEVICE_KIND_KEYBOARD,
+	FU_LOGITECH_HIDPP_DEVICE_KIND_REMOTE_CONTROL,
+	FU_LOGITECH_HIDPP_DEVICE_KIND_NUMPAD,
+	FU_LOGITECH_HIDPP_DEVICE_KIND_MOUSE,
+	FU_LOGITECH_HIDPP_DEVICE_KIND_TOUCHPAD,
+	FU_LOGITECH_HIDPP_DEVICE_KIND_TRACKBALL,
+	FU_LOGITECH_HIDPP_DEVICE_KIND_PRESENTER,
+	FU_LOGITECH_HIDPP_DEVICE_KIND_RECEIVER,
+	FU_LOGITECH_HIDPP_DEVICE_KIND_LAST
 } FuLogitechHidppDeviceKind;
 
 void
 fu_logitech_hidpp_device_set_device_idx(FuLogitechHidppDevice *self, guint8 device_idx)
 {
 	FuLogitechHidppDevicePrivate *priv;
-	g_return_if_fail(FU_IS_HIDPP_DEVICE(self));
+	g_return_if_fail(FU_IS_LOGITECH_HIDPP_DEVICE(self));
 	priv = GET_PRIVATE(self);
 	priv->device_idx = device_idx;
 }
@@ -72,7 +72,7 @@ guint16
 fu_logitech_hidpp_device_get_hidpp_pid(FuLogitechHidppDevice *self)
 {
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
-	g_return_val_if_fail(FU_IS_HIDPP_DEVICE(self), G_MAXUINT16);
+	g_return_val_if_fail(FU_IS_LOGITECH_HIDPP_DEVICE(self), G_MAXUINT16);
 	return priv->hidpp_pid;
 }
 
@@ -80,7 +80,7 @@ void
 fu_logitech_hidpp_device_set_hidpp_pid(FuLogitechHidppDevice *self, guint16 hidpp_pid)
 {
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
-	g_return_if_fail(FU_IS_HIDPP_DEVICE(self));
+	g_return_if_fail(FU_IS_LOGITECH_HIDPP_DEVICE(self));
 	priv->hidpp_pid = hidpp_pid;
 }
 
@@ -88,7 +88,7 @@ static void
 fu_logitech_hidpp_device_set_model_id(FuLogitechHidppDevice *self, const gchar *model_id)
 {
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
-	g_return_if_fail(FU_IS_HIDPP_DEVICE(self));
+	g_return_if_fail(FU_IS_LOGITECH_HIDPP_DEVICE(self));
 	if (g_strcmp0(priv->model_id, model_id) == 0)
 		return;
 	g_free(priv->model_id);
@@ -98,21 +98,21 @@ fu_logitech_hidpp_device_set_model_id(FuLogitechHidppDevice *self, const gchar *
 static const gchar *
 fu_logitech_hidpp_device_get_icon(FuLogitechHidppDeviceKind kind)
 {
-	if (kind == FU_HIDPP_DEVICE_KIND_KEYBOARD)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_KEYBOARD)
 		return FU_DEVICE_ICON_INPUT_KEYBOARD;
-	if (kind == FU_HIDPP_DEVICE_KIND_REMOTE_CONTROL)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_REMOTE_CONTROL)
 		return FU_DEVICE_ICON_PDA; // ish
-	if (kind == FU_HIDPP_DEVICE_KIND_NUMPAD)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_NUMPAD)
 		return FU_DEVICE_ICON_INPUT_DIALPAD;
-	if (kind == FU_HIDPP_DEVICE_KIND_MOUSE)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_MOUSE)
 		return FU_DEVICE_ICON_INPUT_MOUSE;
-	if (kind == FU_HIDPP_DEVICE_KIND_TOUCHPAD)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_TOUCHPAD)
 		return FU_DEVICE_ICON_INPUT_TOUCHPAD;
-	if (kind == FU_HIDPP_DEVICE_KIND_TRACKBALL)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_TRACKBALL)
 		return FU_DEVICE_ICON_INPUT_MOUSE; // ish
-	if (kind == FU_HIDPP_DEVICE_KIND_PRESENTER)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_PRESENTER)
 		return FU_DEVICE_ICON_PDA; // ish
-	if (kind == FU_HIDPP_DEVICE_KIND_RECEIVER)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_RECEIVER)
 		return FU_DEVICE_ICON_USB_RECEIVER;
 	return NULL;
 }
@@ -120,21 +120,21 @@ fu_logitech_hidpp_device_get_icon(FuLogitechHidppDeviceKind kind)
 static const gchar *
 fu_logitech_hidpp_device_get_summary(FuLogitechHidppDeviceKind kind)
 {
-	if (kind == FU_HIDPP_DEVICE_KIND_KEYBOARD)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_KEYBOARD)
 		return "Unifying Keyboard";
-	if (kind == FU_HIDPP_DEVICE_KIND_REMOTE_CONTROL)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_REMOTE_CONTROL)
 		return "Unifying Remote Control";
-	if (kind == FU_HIDPP_DEVICE_KIND_NUMPAD)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_NUMPAD)
 		return "Unifying Number Pad";
-	if (kind == FU_HIDPP_DEVICE_KIND_MOUSE)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_MOUSE)
 		return "Unifying Mouse";
-	if (kind == FU_HIDPP_DEVICE_KIND_TOUCHPAD)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_TOUCHPAD)
 		return "Unifying Touchpad";
-	if (kind == FU_HIDPP_DEVICE_KIND_TRACKBALL)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_TRACKBALL)
 		return "Unifying Trackball";
-	if (kind == FU_HIDPP_DEVICE_KIND_PRESENTER)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_PRESENTER)
 		return "Unifying Presenter";
-	if (kind == FU_HIDPP_DEVICE_KIND_RECEIVER)
+	if (kind == FU_LOGITECH_HIDPP_DEVICE_KIND_RECEIVER)
 		return "Unifying Receiver";
 	return NULL;
 }
@@ -185,7 +185,7 @@ fu_logitech_hidpp_device_ping(FuLogitechHidppDevice *self, GError **error)
 	}
 
 	/* format version in BCD format */
-	if (priv->hidpp_version != FU_HIDPP_VERSION_BLE) {
+	if (priv->hidpp_version != FU_LOGITECH_HIDPP_VERSION_BLE) {
 		/* minor version is in msg->data[1] */;
 		priv->hidpp_version = msg->data[0];
 	}
@@ -197,7 +197,7 @@ fu_logitech_hidpp_device_ping(FuLogitechHidppDevice *self, GError **error)
 static gboolean
 fu_logitech_hidpp_device_poll(FuDevice *device, GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 	const guint timeout = 1; /* ms */
 	g_autoptr(GError) error_local = NULL;
@@ -255,7 +255,7 @@ fu_logitech_hidpp_device_map_to_string(FuLogitechHidppHidppMap *map, guint idt,
 static void
 fu_logitech_hidpp_device_to_string(FuDevice *device, guint idt, GString *str)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 	fwupd_codec_string_append_int(str, idt, "HidppVersion", priv->hidpp_version);
 	fwupd_codec_string_append_int(str, idt, "HidppPid", priv->hidpp_pid);
@@ -363,7 +363,7 @@ fu_logitech_hidpp_device_fetch_firmware_info(FuLogitechHidppDevice *self, GError
 	msg_count->function_id = 0x00 << 4; /* getCount */
 	msg_count->hidpp_version = priv->hidpp_version;
 	if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg_count, error)) {
-		g_prefix_error(error, "failed to get firmware count: ");
+		g_prefix_error_literal(error, "failed to get firmware count: ");
 		return FALSE;
 	}
 	entity_count = msg_count->data[0];
@@ -383,7 +383,7 @@ fu_logitech_hidpp_device_fetch_firmware_info(FuLogitechHidppDevice *self, GError
 		msg->hidpp_version = priv->hidpp_version;
 		msg->data[0] = i;
 		if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-			g_prefix_error(error, "failed to get firmware info: ");
+			g_prefix_error_literal(error, "failed to get firmware info: ");
 			return FALSE;
 		}
 		/* use the single available slot, otherwise -- the slot which is not active */
@@ -414,7 +414,7 @@ fu_logitech_hidpp_device_fetch_firmware_info(FuLogitechHidppDevice *self, GError
 			   fu_device_has_private_flag(FU_DEVICE(self),
 						      FU_LOGITECH_HIDPP_DEVICE_FLAG_ADD_RADIO)) {
 			if (!fu_logitech_hidpp_device_create_radio_child(self, i, build, error)) {
-				g_prefix_error(error, "failed to create radio: ");
+				g_prefix_error_literal(error, "failed to create radio: ");
 				return FALSE;
 			}
 			radio_ok = TRUE;
@@ -427,7 +427,7 @@ fu_logitech_hidpp_device_fetch_firmware_info(FuLogitechHidppDevice *self, GError
 	    !radio_ok) {
 		g_debug("no radio found, creating a fake one for recovery");
 		if (!fu_logitech_hidpp_device_create_radio_child(self, 1, 0, error)) {
-			g_prefix_error(error, "failed to create radio: ");
+			g_prefix_error_literal(error, "failed to create radio: ");
 			return FALSE;
 		}
 	}
@@ -457,7 +457,7 @@ fu_logitech_hidpp_device_fetch_model_id(FuLogitechHidppDevice *self, GError **er
 	msg->function_id = 0x00 << 4; /* getDeviceInfo */
 	msg->hidpp_version = priv->hidpp_version;
 	if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-		g_prefix_error(error, "failed to get the model ID: ");
+		g_prefix_error_literal(error, "failed to get the model ID: ");
 		return FALSE;
 	}
 
@@ -469,7 +469,7 @@ fu_logitech_hidpp_device_fetch_model_id(FuLogitechHidppDevice *self, GError **er
 	/* truncate to 4 chars and convert to a PID */
 	g_string_set_size(str, 4);
 	if (!fu_strtoull(str->str, &pid_tmp, 0, G_MAXUINT32, FU_INTEGER_BASE_16, error)) {
-		g_prefix_error(error, "failed to parse the model ID: ");
+		g_prefix_error_literal(error, "failed to parse the model ID: ");
 		return FALSE;
 	}
 	fu_device_set_pid(FU_DEVICE(self), (guint32)pid_tmp);
@@ -502,14 +502,14 @@ fu_logitech_hidpp_device_fetch_battery_level(FuLogitechHidppDevice *self, GError
 			msg->function_id = 0x00 << 4; /* get_capabilities */
 			msg->hidpp_version = priv->hidpp_version;
 			if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-				g_prefix_error(error, "failed to get battery info: ");
+				g_prefix_error_literal(error, "failed to get battery info: ");
 				return FALSE;
 			}
 			if (msg->data[1] & 0x02)
 				socc = TRUE;
 			msg->function_id = 0x01 << 4; /* get_status */
 			if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-				g_prefix_error(error, "failed to get battery info: ");
+				g_prefix_error_literal(error, "failed to get battery info: ");
 				return FALSE;
 			}
 			if (socc) {
@@ -548,7 +548,7 @@ fu_logitech_hidpp_device_fetch_battery_level(FuLogitechHidppDevice *self, GError
 			msg->function_id = 0x00 << 4; /* GetBatteryLevelStatus */
 			msg->hidpp_version = priv->hidpp_version;
 			if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-				g_prefix_error(error, "failed to get battery info: ");
+				g_prefix_error_literal(error, "failed to get battery info: ");
 				return FALSE;
 			}
 			if (msg->data[0] != 0x00)
@@ -656,7 +656,7 @@ fu_logitech_hidpp_device_rdfu_get_capabilities(FuLogitechHidppDevice *self, GErr
 
 	g_debug("read capabilities");
 	if (!fu_logitech_hidpp_device_transfer_msg(self, msg, error)) {
-		g_prefix_error(error, "failed to get capabilities: ");
+		g_prefix_error_literal(error, "failed to get capabilities: ");
 		return FALSE;
 	}
 
@@ -697,7 +697,7 @@ fu_logitech_hidpp_device_rdfu_start_dfu(FuLogitechHidppDevice *self,
 
 	g_debug("startDfu");
 	if (!fu_logitech_hidpp_device_transfer_msg(self, msg, error)) {
-		g_prefix_error(error, "startDfu failed: ");
+		g_prefix_error_literal(error, "startDfu failed: ");
 		return FALSE;
 	}
 
@@ -971,7 +971,7 @@ fu_logitech_hidpp_device_rdfu_get_dfu_status(FuLogitechHidppDevice *self, GError
 
 	g_debug("getDfuStatus for entity %u", priv->cached_fw_entity);
 	if (!fu_logitech_hidpp_device_transfer_msg(self, msg, error)) {
-		g_prefix_error(error, "getDfuStatus failed: ");
+		g_prefix_error_literal(error, "getDfuStatus failed: ");
 		return FALSE;
 	}
 
@@ -989,7 +989,7 @@ fu_logitech_hidpp_device_rdfu_apply_dfu(FuLogitechHidppDevice *self,
 {
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 	guint8 idx;
-	guint8 flags = FU_LOGITECH_HIDPP_RDFU_APPLY_FLAGS_FORCE_DFU_BIT;
+	guint8 flags = FU_LOGITECH_HIDPP_RDFU_APPLY_FLAG_FORCE_DFU_BIT;
 	g_autoptr(FuStructLogitechHidppRdfuApplyDfu) msg =
 	    fu_struct_logitech_hidpp_rdfu_apply_dfu_new();
 	FuLogitechHidppHidppMsg *hidpp_msg = NULL;
@@ -1019,7 +1019,7 @@ fu_logitech_hidpp_device_rdfu_apply_dfu(FuLogitechHidppDevice *self,
 	fu_struct_logitech_hidpp_rdfu_apply_dfu_set_fw_entity(msg, fw_entity);
 	fu_struct_logitech_hidpp_rdfu_apply_dfu_set_flags(msg, flags);
 
-	/* re-use pre-rustgen send */
+	/* reuse pre-rustgen send */
 	hidpp_msg = (FuLogitechHidppHidppMsg *)msg->data;
 	hidpp_msg->hidpp_version = priv->hidpp_version;
 	/* don't expect the reply for forced applyDfu */
@@ -1062,7 +1062,7 @@ fu_logitech_hidpp_device_rdfu_transfer_pkt(FuLogitechHidppDevice *self,
 
 	g_debug("transferDfuData");
 	if (!fu_logitech_hidpp_device_transfer_msg(self, msg, error)) {
-		g_prefix_error(error, "transferDfuData failed: ");
+		g_prefix_error_literal(error, "transferDfuData failed: ");
 		return FALSE;
 	}
 
@@ -1163,7 +1163,7 @@ fu_logitech_hidpp_device_feature_search(FuLogitechHidppDevice *self,
 static gboolean
 fu_logitech_hidpp_device_probe(FuDevice *device, GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 
 	/* nearly... */
@@ -1207,7 +1207,7 @@ fu_logitech_hidpp_device_write_firmware_pkt(FuLogitechHidppDevice *self,
 static gboolean
 fu_logitech_hidpp_device_setup(FuDevice *device, GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 	guint8 idx;
 	const guint16 map_features[] = {FU_LOGITECH_HIDPP_FEATURE_GET_DEVICE_NAME_TYPE,
@@ -1222,7 +1222,7 @@ fu_logitech_hidpp_device_setup(FuDevice *device, GError **error)
 					FU_LOGITECH_HIDPP_FEATURE_ROOT};
 
 	if (fu_device_has_private_flag(device, FU_LOGITECH_HIDPP_DEVICE_FLAG_BLE)) {
-		priv->hidpp_version = FU_HIDPP_VERSION_BLE;
+		priv->hidpp_version = FU_LOGITECH_HIDPP_VERSION_BLE;
 		priv->device_idx = FU_LOGITECH_HIDPP_DEVICE_IDX_RECEIVER;
 		/*
 		 * BLE devices might not be ready for ping right after
@@ -1282,7 +1282,7 @@ fu_logitech_hidpp_device_setup(FuDevice *device, GError **error)
 		msg->function_id = 0x02 << 4; /* getDeviceType */
 		msg->hidpp_version = priv->hidpp_version;
 		if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-			g_prefix_error(error, "failed to get device type: ");
+			g_prefix_error_literal(error, "failed to get device type: ");
 			return FALSE;
 		}
 
@@ -1316,7 +1316,7 @@ fu_logitech_hidpp_device_setup(FuDevice *device, GError **error)
 		msg->function_id = 0x00 << 4; /* getDfuStatus */
 		msg->hidpp_version = priv->hidpp_version;
 		if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-			g_prefix_error(error, "failed to get DFU status: ");
+			g_prefix_error_literal(error, "failed to get DFU status: ");
 			return FALSE;
 		}
 		if ((msg->data[2] & 0x01) > 0) {
@@ -1362,14 +1362,14 @@ fu_logitech_hidpp_device_setup(FuDevice *device, GError **error)
 		fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
 	}
 	/* poll for pings to track active state */
-	fu_device_set_poll_interval(device, FU_HIDPP_DEVICE_POLLING_INTERVAL);
+	fu_device_set_poll_interval(device, FU_LOGITECH_HIDPP_DEVICE_POLLING_INTERVAL);
 	return TRUE;
 }
 
 static gboolean
 fu_logitech_hidpp_device_detach(FuDevice *device, FuProgress *progress, GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 	guint8 idx;
 	g_autoptr(FuLogitechHidppHidppMsg) msg = fu_logitech_hidpp_msg_new();
@@ -1471,7 +1471,7 @@ fu_logitech_hidpp_device_detach(FuDevice *device, FuProgress *progress, GError *
 		msg->data[6] = 'U';
 		msg->flags = FU_LOGITECH_HIDPP_HIDPP_MSG_FLAG_IGNORE_SUB_ID;
 		if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-			g_prefix_error(error, "failed to put device into DFU mode: ");
+			g_prefix_error_literal(error, "failed to put device into DFU mode: ");
 			return FALSE;
 		}
 		fu_device_sleep(device, 200); /* ms */
@@ -1573,7 +1573,7 @@ fu_logitech_hidpp_device_write_firmware_pkt(FuLogitechHidppDevice *self,
 			    error))
 		return FALSE;
 	if (!fu_logitech_hidpp_transfer(FU_UDEV_DEVICE(self), msg, error)) {
-		g_prefix_error(error, "failed to supply program data: ");
+		g_prefix_error_literal(error, "failed to supply program data: ");
 		return FALSE;
 	}
 
@@ -1628,7 +1628,7 @@ fu_logitech_hidpp_device_write_firmware_dfu(FuDevice *device,
 					    FwupdInstallFlags flags,
 					    GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 	gsize sz = 0;
 	const guint8 *data;
@@ -1639,10 +1639,10 @@ fu_logitech_hidpp_device_write_firmware_dfu(FuDevice *device,
 	/* if we're in bootloader mode, we should be able to get this feature */
 	idx = fu_logitech_hidpp_device_feature_get_idx(self, FU_LOGITECH_HIDPP_FEATURE_DFU);
 	if (idx == 0x00) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOT_SUPPORTED,
-			    "no DFU feature available");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "no DFU feature available");
 		return FALSE;
 	}
 
@@ -1687,7 +1687,7 @@ fu_logitech_hidpp_device_write_firmware_rdfu(FuDevice *device,
 					     FwupdInstallFlags flags,
 					     GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 	FuLogitechRdfuFirmware *entity_fw = NULL;
 	guint8 idx;
@@ -1767,10 +1767,10 @@ fu_logitech_hidpp_device_write_firmware_rdfu(FuDevice *device,
 
 			/* too many soft restarts, let's fail everything */
 			if (retry++ > FU_LOGITECH_HIDPP_DEVICE_RDFU_MAX_RETRIES) {
-				g_set_error(error,
-					    FWUPD_ERROR,
-					    FWUPD_ERROR_WRITE,
-					    "too lot recover attempts");
+				g_set_error_literal(error,
+						    FWUPD_ERROR,
+						    FWUPD_ERROR_WRITE,
+						    "too lot recover attempts");
 				return FALSE;
 			}
 		}
@@ -1792,7 +1792,7 @@ fu_logitech_hidpp_device_write_firmware(FuDevice *device,
 					FwupdInstallFlags flags,
 					GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	guint8 idx;
 	g_autoptr(GBytes) fw = NULL;
 
@@ -1816,10 +1816,10 @@ fu_logitech_hidpp_device_write_firmware(FuDevice *device,
 								   error);
 	}
 
-	g_set_error(error,
-		    FWUPD_ERROR,
-		    FWUPD_ERROR_NOT_SUPPORTED,
-		    "no DFU or RDFU feature available");
+	g_set_error_literal(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_NOT_SUPPORTED,
+			    "no DFU or RDFU feature available");
 	return FALSE;
 }
 
@@ -1852,10 +1852,10 @@ fu_logitech_hidpp_device_attach(FuLogitechHidppDevice *self,
 		/* if we're in bootloader mode, we should be able to get this feature */
 		idx = fu_logitech_hidpp_device_feature_get_idx(self, FU_LOGITECH_HIDPP_FEATURE_DFU);
 		if (idx == 0x00) {
-			g_set_error(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_SUPPORTED,
-				    "no DFU feature available");
+			g_set_error_literal(error,
+					    FWUPD_ERROR,
+					    FWUPD_ERROR_NOT_SUPPORTED,
+					    "no DFU feature available");
 			return FALSE;
 		}
 
@@ -1898,7 +1898,7 @@ fu_logitech_hidpp_device_attach(FuLogitechHidppDevice *self,
 static gboolean
 fu_logitech_hidpp_device_attach_cached(FuDevice *device, FuProgress *progress, GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 
 	if (fu_device_has_private_flag(device, FU_LOGITECH_HIDPP_DEVICE_FLAG_REBIND_ATTACH))
@@ -1912,7 +1912,7 @@ fu_logitech_hidpp_device_set_quirk_kv(FuDevice *device,
 				      const gchar *value,
 				      GError **error)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(device);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(device);
 	if (g_strcmp0(key, "LogitechHidppModelId") == 0) {
 		fu_logitech_hidpp_device_set_model_id(self, value);
 		return TRUE;
@@ -1938,7 +1938,7 @@ fu_logitech_hidpp_device_set_progress(FuDevice *self, FuProgress *progress)
 static void
 fu_logitech_hidpp_device_finalize(GObject *object)
 {
-	FuLogitechHidppDevice *self = FU_HIDPP_DEVICE(object);
+	FuLogitechHidppDevice *self = FU_LOGITECH_HIDPP_DEVICE(object);
 	FuLogitechHidppDevicePrivate *priv = GET_PRIVATE(self);
 	g_ptr_array_unref(priv->feature_index);
 	g_free(priv->model_id);
@@ -1953,7 +1953,8 @@ fu_logitech_hidpp_device_cleanup(FuDevice *device,
 {
 	FuDevice *parent = fu_device_get_parent(device);
 	if (parent != NULL)
-		fu_device_set_poll_interval(parent, FU_HIDPP_RECEIVER_RUNTIME_POLLING_INTERVAL);
+		fu_device_set_poll_interval(parent,
+					    FU_LOGITECH_HIDPP_RECEIVER_RUNTIME_POLLING_INTERVAL);
 
 	return TRUE;
 }
@@ -1988,7 +1989,6 @@ fu_logitech_hidpp_device_init(FuLogitechHidppDevice *self)
 	fu_device_set_vid(FU_DEVICE(self), FU_LOGITECH_HIDPP_DEVICE_VID);
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_PLAIN);
-	fu_device_set_vendor(FU_DEVICE(self), "Logitech");
 	fu_device_retry_set_delay(FU_DEVICE(self), 1000);
 	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_READ);
 	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_WRITE);
@@ -2015,7 +2015,7 @@ fu_logitech_hidpp_device_init(FuLogitechHidppDevice *self)
 FuLogitechHidppDevice *
 fu_logitech_hidpp_device_new(FuUdevDevice *parent)
 {
-	return g_object_new(FU_TYPE_HIDPP_DEVICE,
+	return g_object_new(FU_TYPE_LOGITECH_HIDPP_DEVICE,
 			    "proxy",
 			    parent,
 			    "device-file",
