@@ -13,6 +13,7 @@
 #include <string.h>
 
 #include "fu-logitech-scribe-device.h"
+#include "fu-logitech-scribe-struct.h"
 
 /* UPD interface follows TLV (Type, Length, Value) protocol */
 /* Payload size limited to 8k for UPD interfaces            */
@@ -37,21 +38,6 @@ enum { EP_OUT, EP_IN, EP_LAST };
 
 enum { BULK_INTERFACE_UPD };
 
-typedef enum {
-	CMD_CHECK_BUFFERSIZE = 0xCC00,
-	CMD_INIT = 0xCC01,
-	CMD_START_TRANSFER = 0xCC02,
-	CMD_DATA_TRANSFER = 0xCC03,
-	CMD_END_TRANSFER = 0xCC04,
-	CMD_UNINIT = 0xCC05,
-	CMD_BUFFER_READ = 0xCC06,
-	CMD_BUFFER_WRITE = 0xCC07,
-	CMD_UNINIT_BUFFER = 0xCC08,
-	CMD_ACK = 0xFF01,
-	CMD_TIMEOUT = 0xFF02,
-	CMD_NACK = 0xFF03
-} UsbCommands;
-
 #define FU_LOGITECH_SCRIBE_DEVICE_IOCTL_TIMEOUT 5000 /* ms */
 /* 2 byte for get len query */
 #define kDefaultUvcGetLenQueryControlSize 2
@@ -106,7 +92,7 @@ fu_logitech_scribe_device_send(FuLogitechScribeDevice *self,
 					 BULK_TRANSFER_TIMEOUT,
 					 cancellable,
 					 error)) {
-		g_prefix_error(error, "failed to send using bulk transfer: ");
+		g_prefix_error_literal(error, "failed to send using bulk transfer: ");
 		return FALSE;
 	}
 	return TRUE;
@@ -141,7 +127,7 @@ fu_logitech_scribe_device_recv(FuLogitechScribeDevice *self,
 					 timeout,
 					 NULL,
 					 error)) {
-		g_prefix_error(error, "failed to receive: ");
+		g_prefix_error_literal(error, "failed to receive: ");
 		return FALSE;
 	}
 	return TRUE;
@@ -176,7 +162,7 @@ fu_logitech_scribe_device_send_upd_cmd(FuLogitechScribeDevice *self,
 
 	/* extending the bulk transfer timeout value, as android device takes some time to
 	   calculate Hash and respond */
-	if (CMD_END_TRANSFER == cmd)
+	if (FU_LOGITECH_SCRIBE_USB_CMD_END_TRANSFER == cmd)
 		timeout = HASH_TIMEOUT;
 
 	if (!fu_logitech_scribe_device_recv(self,
@@ -194,11 +180,11 @@ fu_logitech_scribe_device_send_upd_cmd(FuLogitechScribeDevice *self,
 				    G_LITTLE_ENDIAN,
 				    error))
 		return FALSE;
-	if (cmd_tmp != CMD_ACK) {
+	if (cmd_tmp != FU_LOGITECH_SCRIBE_USB_CMD_ACK) {
 		g_set_error(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_INVALID_DATA,
-			    "not CMD_ACK, got %x",
+			    "not FU_LOGITECH_SCRIBE_USB_CMD_ACK, got %x",
 			    cmd);
 		return FALSE;
 	}
@@ -380,7 +366,11 @@ static gboolean
 fu_logitech_scribe_device_send_upd_init_cmd_cb(FuDevice *device, gpointer user_data, GError **error)
 {
 	FuLogitechScribeDevice *self = FU_LOGITECH_SCRIBE_DEVICE(device);
-	return fu_logitech_scribe_device_send_upd_cmd(self, user_data, CMD_INIT, NULL, error);
+	return fu_logitech_scribe_device_send_upd_cmd(self,
+						      user_data,
+						      FU_LOGITECH_SCRIBE_USB_CMD_INIT,
+						      NULL,
+						      error);
 }
 
 static gboolean
@@ -410,11 +400,12 @@ fu_logitech_scribe_device_write_fw(FuLogitechScribeDevice *self,
 		if (chk == NULL)
 			return FALSE;
 		g_byte_array_append(data_pkt, fu_chunk_get_data(chk), fu_chunk_get_data_sz(chk));
-		if (!fu_logitech_scribe_device_send_upd_cmd(self,
-							    usb_device,
-							    CMD_DATA_TRANSFER,
-							    data_pkt,
-							    error)) {
+		if (!fu_logitech_scribe_device_send_upd_cmd(
+			self,
+			usb_device,
+			FU_LOGITECH_SCRIBE_USB_CMD_DATA_TRANSFER,
+			data_pkt,
+			error)) {
 			g_prefix_error(error, "failed to send data packet 0x%x: ", i);
 			return FALSE;
 		}
@@ -492,6 +483,7 @@ fu_logitech_scribe_device_write_firmware(FuDevice *device,
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "device-write-blocks");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, "end-transfer");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 5, "uninit");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 10, "sleep");
 
 	/* get default image */
 	stream = fu_firmware_get_stream(firmware, error);
@@ -504,8 +496,9 @@ fu_logitech_scribe_device_write_firmware(FuDevice *device,
 			     MAX_RETRIES,
 			     usb_device,
 			     error)) {
-		g_prefix_error(error,
-			       "failed to write init transfer packet: please reboot the device: ");
+		g_prefix_error_literal(
+		    error,
+		    "failed to write init transfer packet: please reboot the device: ");
 		return FALSE;
 	}
 	fu_progress_step_done(progress);
@@ -516,10 +509,10 @@ fu_logitech_scribe_device_write_firmware(FuDevice *device,
 	fu_byte_array_append_uint64(start_pkt, streamsz, G_LITTLE_ENDIAN);
 	if (!fu_logitech_scribe_device_send_upd_cmd(self,
 						    usb_device,
-						    CMD_START_TRANSFER,
+						    FU_LOGITECH_SCRIBE_USB_CMD_START_TRANSFER,
 						    start_pkt,
 						    error)) {
-		g_prefix_error(error, "failed to write start transfer packet: ");
+		g_prefix_error_literal(error, "failed to write start transfer packet: ");
 		return FALSE;
 	}
 	fu_progress_step_done(progress);
@@ -545,10 +538,10 @@ fu_logitech_scribe_device_write_firmware(FuDevice *device,
 	g_byte_array_append(end_pkt, (const guint8 *)base64hash, strlen(base64hash));
 	if (!fu_logitech_scribe_device_send_upd_cmd(self,
 						    usb_device,
-						    CMD_END_TRANSFER,
+						    FU_LOGITECH_SCRIBE_USB_CMD_END_TRANSFER,
 						    end_pkt,
 						    error)) {
-		g_prefix_error(error, "failed to write end transfer packet: ");
+		g_prefix_error_literal(error, "failed to write end transfer packet: ");
 		return FALSE;
 	}
 	fu_progress_step_done(progress);
@@ -557,7 +550,7 @@ fu_logitech_scribe_device_write_firmware(FuDevice *device,
 	/* no need to wait for ACK message, perhaps device reboot already in progress, ignore */
 	if (!fu_logitech_scribe_device_send_upd_cmd(self,
 						    usb_device,
-						    CMD_UNINIT,
+						    FU_LOGITECH_SCRIBE_USB_CMD_UNINIT,
 						    NULL,
 						    &error_local)) {
 		g_debug(
@@ -570,6 +563,9 @@ fu_logitech_scribe_device_write_firmware(FuDevice *device,
 	 * image file pushed. Device validates and uploads new image on inactive partition. Reboots
 	 * wait for RemoveDelay duration
 	 */
+	fu_device_sleep_full(FU_DEVICE(self), 60 * 1000, fu_progress_get_child(progress));
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
+	fu_progress_step_done(progress);
 
 	/* success! */
 	return TRUE;
@@ -639,6 +635,7 @@ static void
 fu_logitech_scribe_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 100, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "attach");
@@ -659,6 +656,8 @@ fu_logitech_scribe_device_init(FuLogitechScribeDevice *self)
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
 	fu_device_retry_set_delay(FU_DEVICE(self), 1000);
+	fu_device_set_remove_delay(FU_DEVICE(self), 2 * 60 * 1000);
+	fu_device_set_install_duration(FU_DEVICE(self), 120);
 }
 
 static void
