@@ -34,7 +34,8 @@
 #define IPMI_PASSWORD_SET_PASSWORD  0x02
 #define IPMI_PASSWORD_TEST_PASSWORD 0x03
 
-/* these are not provided in ipmi_msgdefs.h */
+/* these are not provided in ipmi_msgdefs.h,
+ * nocheck:magic-defines=50 */
 #define IPMI_INVALID_COMMAND_ON_LUN_ERR	 0xC2
 #define IPMI_OUT_OF_SPACE_ERR		 0xC4
 #define IPMI_CANCELLED_OR_INVALID_ERR	 0xC5
@@ -560,7 +561,7 @@ fu_ipmi_device_get_user_password(FuIpmiDevice *self, guint8 user_id, GError **er
 					&resp_len,
 					FU_IPMI_DEVICE_TIMEOUT,
 					error)) {
-		g_prefix_error(error, "failed to get username: ");
+		g_prefix_error_literal(error, "failed to get username: ");
 		return NULL;
 	}
 	if (resp_len != sizeof(resp)) {
@@ -599,7 +600,7 @@ fu_ipmi_device_set_user_name(FuIpmiDevice *self,
 			    0x0, /* src */
 			    username_sz,
 			    error)) {
-		g_prefix_error(error, "username invalid: ");
+		g_prefix_error_literal(error, "username invalid: ");
 		return FALSE;
 	}
 
@@ -673,7 +674,7 @@ fu_ipmi_device_set_user_password(FuIpmiDevice *self,
 			    0x0, /* src */
 			    password_sz,
 			    error)) {
-		g_prefix_error(error, "password invalid: ");
+		g_prefix_error_literal(error, "password invalid: ");
 		return FALSE;
 	}
 
@@ -769,8 +770,10 @@ fu_ipmi_device_init(FuIpmiDevice *self)
 {
 	fu_device_set_name(FU_DEVICE(self), "IPMI");
 	fu_device_set_summary(FU_DEVICE(self), "Intelligent Platform Management Interface");
-	fu_device_add_icon(FU_DEVICE(self), "computer");
+	fu_device_add_icon(FU_DEVICE(self), FU_DEVICE_ICON_COMPUTER);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_INTERNAL);
+	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_READ);
+	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_WRITE);
 }
 
 static void
