@@ -10,6 +10,7 @@
 
 #include "fu-redfish-backend.h"
 #include "fu-redfish-common.h"
+#include "fu-redfish-hpe-device.h"
 #include "fu-redfish-legacy-device.h"
 #include "fu-redfish-multipart-device.h"
 #include "fu-redfish-request.h"
@@ -21,6 +22,7 @@ struct _FuRedfishBackend {
 	gchar *hostname;
 	gchar *username;
 	gchar *password;
+	gchar *session_key;
 	guint port;
 	gchar *vendor;
 	gchar *version;
@@ -31,6 +33,7 @@ struct _FuRedfishBackend {
 	gboolean cacheck;
 	gboolean wildcard_targets;
 	gint64 max_image_size; /* bytes */
+	gchar *system_id;
 	GType device_gtype;
 	GHashTable *request_cache; /* str:GByteArray */
 	CURLSH *curlsh;
@@ -114,6 +117,15 @@ fu_redfish_backend_coldplug_member(FuRedfishBackend *self, JsonObject *member, G
 			   member,
 			   NULL);
 
+	/* Dell specific currently */
+	if (self->system_id != NULL) {
+		fu_device_add_instance_str(dev, "SYSTEMID", self->system_id);
+		/* Ensure the reboot is not done immediately after installation, and only after a
+		 * wanted reboot */
+		fu_redfish_multipart_device_set_apply_time(FU_REDFISH_MULTIPART_DEVICE(dev),
+							   "OnReset");
+	}
+
 	/* some vendors do not specify the Targets array when updating */
 	if (self->wildcard_targets)
 		fu_device_add_private_flag(dev, FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS);
@@ -224,6 +236,64 @@ fu_redfish_backend_check_wildcard_targets(FuRedfishBackend *self)
 	}
 }
 
+static void
+fu_redfish_backend_set_session_key(FuRedfishBackend *self, const gchar *session_key)
+{
+	g_free(self->session_key);
+	self->session_key = g_strdup(session_key);
+}
+
+static size_t
+fu_redfish_backend_session_headers_callback(char *ptr, size_t size, size_t nmemb, void *userdata)
+{
+	FuRedfishBackend *self = FU_REDFISH_BACKEND(userdata);
+	if ((size * nmemb) > 16 && g_ascii_strncasecmp(ptr, "X-Auth-Token:", 13) == 0) {
+		g_autofree gchar *session_key = NULL;
+		/* The string also includes \r\n at the end */
+		session_key = g_strndup(ptr + 14, (size * nmemb) - 16);
+		fu_redfish_backend_set_session_key(self, session_key);
+	}
+	return size * nmemb;
+}
+
+gboolean
+fu_redfish_backend_create_session(FuRedfishBackend *self, GError **error)
+{
+	g_autoptr(FuRedfishRequest) request = fu_redfish_backend_request_new(self);
+	g_autoptr(JsonBuilder) builder = json_builder_new();
+
+	json_builder_begin_object(builder);
+	json_builder_set_member_name(builder, "UserName");
+	json_builder_add_string_value(builder, self->username);
+	json_builder_set_member_name(builder, "Password");
+	json_builder_add_string_value(builder, self->password);
+	json_builder_end_object(builder);
+
+	(void)curl_easy_setopt(fu_redfish_request_get_curl(request), CURLOPT_HEADERDATA, self);
+	(void)curl_easy_setopt(fu_redfish_request_get_curl(request),
+			       CURLOPT_HEADERFUNCTION,
+			       fu_redfish_backend_session_headers_callback);
+
+	/* create URI and poll */
+	if (!fu_redfish_request_perform_full(request,
+					     "/redfish/v1/SessionService/Sessions",
+					     "POST",
+					     builder,
+					     FU_REDFISH_REQUEST_PERFORM_FLAG_LOAD_JSON,
+					     error))
+		return FALSE;
+	if (fu_redfish_backend_get_session_key(self) == NULL) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INTERNAL,
+				    "failed to get session key");
+		return FALSE;
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static void
 fu_redfish_backend_set_push_uri_path(FuRedfishBackend *self, const gchar *push_uri_path)
 {
@@ -282,7 +352,8 @@ fu_redfish_backend_coldplug(FuBackend *backend, FuProgress *progress, GError **e
 	    json_object_has_member(json_obj, "MultipartHttpPushUri")) {
 		const gchar *tmp = json_object_get_string_member(json_obj, "MultipartHttpPushUri");
 		if (tmp != NULL) {
-			if (fu_redfish_backend_has_smc_update_path(json_obj)) {
+			if (g_strcmp0(self->vendor, "SMCI") == 0 &&
+			    fu_redfish_backend_has_smc_update_path(json_obj)) {
 				self->device_gtype = FU_TYPE_REDFISH_SMC_DEVICE;
 			} else {
 				self->device_gtype = FU_TYPE_REDFISH_MULTIPART_DEVICE;
@@ -293,7 +364,10 @@ fu_redfish_backend_coldplug(FuBackend *backend, FuProgress *progress, GError **e
 	if (self->push_uri_path == NULL && json_object_has_member(json_obj, "HttpPushUri")) {
 		const gchar *tmp = json_object_get_string_member(json_obj, "HttpPushUri");
 		if (tmp != NULL) {
-			self->device_gtype = FU_TYPE_REDFISH_LEGACY_DEVICE;
+			if (self->vendor != NULL && g_str_equal(self->vendor, "HPE"))
+				self->device_gtype = FU_TYPE_REDFISH_HPE_DEVICE;
+			else
+				self->device_gtype = FU_TYPE_REDFISH_LEGACY_DEVICE;
 			fu_redfish_backend_set_push_uri_path(self, tmp);
 		}
 	}
@@ -335,6 +409,112 @@ fu_redfish_backend_set_update_uri_path(FuRedfishBackend *self, const gchar *upda
 	self->update_uri_path = g_strdup(update_uri_path);
 }
 
+static gboolean
+fu_redfish_backend_setup_dell_member(FuRedfishBackend *self,
+				     const gchar *member_uri,
+				     GError **error)
+{
+	JsonObject *dell_obj;
+	JsonObject *dell_system_obj;
+	JsonObject *json_obj;
+	JsonObject *oem_obj;
+	g_autoptr(FuRedfishRequest) request = fu_redfish_backend_request_new(self);
+
+	if (!fu_redfish_request_perform(request,
+					member_uri,
+					FU_REDFISH_REQUEST_PERFORM_FLAG_LOAD_JSON,
+					error))
+		return FALSE;
+	json_obj = fu_redfish_request_get_json_object(request);
+	if (!json_object_has_member(json_obj, "Oem")) {
+		g_set_error_literal(error, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND, "no Oem in Member");
+		return FALSE;
+	}
+	oem_obj = json_object_get_object_member(json_obj, "Oem");
+	if (oem_obj == NULL) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_FOUND,
+				    "no valid Oem in Member");
+		return FALSE;
+	}
+	if (!json_object_has_member(oem_obj, "Dell")) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_FOUND,
+				    "no OEM/Dell in Member");
+		return FALSE;
+	}
+	dell_obj = json_object_get_object_member(oem_obj, "Dell");
+	if (dell_obj == NULL) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_FOUND,
+				    "no valid OEM/Dell in Member");
+		return FALSE;
+	}
+	if (!json_object_has_member(dell_obj, "DellSystem")) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_FOUND,
+				    "no OEM/Dell/DellSystem in Member");
+		return FALSE;
+	}
+	dell_system_obj = json_object_get_object_member(dell_obj, "DellSystem");
+	if (dell_system_obj == NULL) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_FOUND,
+				    "no valid OEM/Dell/DellSystem in Member");
+		return FALSE;
+	}
+	if (!json_object_has_member(dell_system_obj, "SystemID")) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_FOUND,
+				    "no OEM/Dell/DellSystem/SystemID in Member");
+		return FALSE;
+	}
+
+	/* success */
+	self->system_id =
+	    g_strdup_printf("%04X",
+			    (guint16)json_object_get_int_member(dell_system_obj, "SystemID"));
+	return TRUE;
+}
+
+static gboolean
+fu_redfish_backend_setup_dell(FuRedfishBackend *self, GError **error)
+{
+	JsonObject *member;
+	JsonArray *members;
+	JsonObject *json_obj;
+	const gchar *member_uri;
+	g_autoptr(FuRedfishRequest) request = fu_redfish_backend_request_new(self);
+
+	if (!fu_redfish_request_perform(request,
+					"/redfish/v1/Systems",
+					FU_REDFISH_REQUEST_PERFORM_FLAG_LOAD_JSON,
+					error))
+		return FALSE;
+	json_obj = fu_redfish_request_get_json_object(request);
+	if (!json_object_has_member(json_obj, "Members")) {
+		g_set_error_literal(error, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND, "no Members object");
+		return FALSE;
+	}
+	members = json_object_get_array_member(json_obj, "Members");
+	if (json_array_get_length(members) == 0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_FOUND,
+				    "empty Members array");
+		return FALSE;
+	}
+	member = json_array_get_object_element(members, 0);
+	member_uri = json_object_get_string_member(member, "@odata.id");
+	return fu_redfish_backend_setup_dell_member(self, member_uri, error);
+}
+
 static gboolean
 fu_redfish_backend_setup(FuBackend *backend,
 			 FuBackendSetupFlags flags,
@@ -382,7 +562,10 @@ fu_redfish_backend_setup(FuBackend *backend,
 		g_free(self->vendor);
 		self->vendor = g_strdup(json_object_get_string_member(json_obj, "Vendor"));
 	}
-
+	if (g_strcmp0(self->vendor, "Dell") == 0) {
+		if (!fu_redfish_backend_setup_dell(self, error))
+			return FALSE;
+	}
 	if (json_object_has_member(json_obj, "UpdateService"))
 		json_update_service = json_object_get_object_member(json_obj, "UpdateService");
 	if (json_update_service == NULL) {
@@ -468,6 +651,12 @@ fu_redfish_backend_get_push_uri_path(FuRedfishBackend *self)
 	return self->push_uri_path;
 }
 
+const gchar *
+fu_redfish_backend_get_session_key(FuRedfishBackend *self)
+{
+	return self->session_key;
+}
+
 static void
 fu_redfish_backend_to_string(FuBackend *backend, guint idt, GString *str)
 {
@@ -475,6 +664,7 @@ fu_redfish_backend_to_string(FuBackend *backend, guint idt, GString *str)
 	fwupd_codec_string_append(str, idt, "Hostname", self->hostname);
 	fwupd_codec_string_append(str, idt, "Username", self->username);
 	fwupd_codec_string_append_bool(str, idt, "Password", self->password != NULL);
+	fwupd_codec_string_append(str, idt, "SessionKey", self->session_key);
 	fwupd_codec_string_append_int(str, idt, "Port", self->port);
 	fwupd_codec_string_append(str, idt, "UpdateUriPath", self->update_uri_path);
 	fwupd_codec_string_append(str, idt, "PushUriPath", self->push_uri_path);
@@ -482,6 +672,7 @@ fu_redfish_backend_to_string(FuBackend *backend, guint idt, GString *str)
 	fwupd_codec_string_append_bool(str, idt, "Cacheck", self->cacheck);
 	fwupd_codec_string_append_bool(str, idt, "WildcardTargets", self->wildcard_targets);
 	fwupd_codec_string_append_hex(str, idt, "MaxImageSize", self->max_image_size);
+	fwupd_codec_string_append(str, idt, "SystemId", self->system_id);
 	fwupd_codec_string_append(str, idt, "DeviceGType", g_type_name(self->device_gtype));
 }
 
@@ -496,9 +687,11 @@ fu_redfish_backend_finalize(GObject *object)
 	g_free(self->hostname);
 	g_free(self->username);
 	g_free(self->password);
+	g_free(self->session_key);
 	g_free(self->vendor);
 	g_free(self->version);
 	g_free(self->uuid);
+	g_free(self->system_id);
 	G_OBJECT_CLASS(fu_redfish_backend_parent_class)->finalize(object);
 }
 
