@@ -10,10 +10,10 @@
 #include "fu-ipmi-device.h"
 #endif
 
-#include "fu-ipmi-device.h"
 #include "fu-redfish-backend.h"
 #include "fu-redfish-common.h"
 #include "fu-redfish-device.h"
+#include "fu-redfish-hpe-device.h"
 #include "fu-redfish-legacy-device.h"
 #include "fu-redfish-multipart-device.h"
 #include "fu-redfish-network.h"
@@ -147,6 +147,18 @@ fu_redfish_plugin_set_credentials(FuPlugin *plugin, const gchar *username, const
 	fu_redfish_backend_set_password(self->backend, password);
 }
 
+gboolean
+fu_redfish_plugin_reload(FuPlugin *plugin, FuProgress *progress, GError **error)
+{
+	FuRedfishPlugin *self = FU_REDFISH_PLUGIN(plugin);
+
+	fu_backend_invalidate(FU_BACKEND(self->backend));
+	return fu_backend_setup(FU_BACKEND(self->backend),
+				FU_BACKEND_SETUP_FLAG_NONE,
+				progress,
+				error);
+}
+
 static gboolean
 fu_redfish_plugin_discover_uefi_credentials(FuPlugin *plugin, GError **error)
 {
@@ -217,7 +229,7 @@ fu_redfish_plugin_discover_smbios_table(FuPlugin *plugin, GError **error)
 	if (smbios_data_fn != NULL) {
 		g_autoptr(FuRedfishSmbios) smbios = fu_redfish_smbios_new();
 		if (!fu_firmware_build_from_filename(FU_FIRMWARE(smbios), smbios_data_fn, error)) {
-			g_prefix_error(error, "failed to build SMBIOS entry type 42: ");
+			g_prefix_error_literal(error, "failed to build SMBIOS entry type 42: ");
 			return FALSE;
 		}
 		g_set_object(&self->smbios, smbios);
@@ -225,7 +237,10 @@ fu_redfish_plugin_discover_smbios_table(FuPlugin *plugin, GError **error)
 	}
 
 	/* is optional */
-	type42_tables = fu_context_get_smbios_data(ctx, REDFISH_SMBIOS_TABLE_TYPE, NULL);
+	type42_tables = fu_context_get_smbios_data(ctx,
+						   REDFISH_SMBIOS_TABLE_TYPE,
+						   FU_SMBIOS_STRUCTURE_LENGTH_ANY,
+						   NULL);
 	if (type42_tables == NULL)
 		return TRUE;
 	for (guint i = 0; i < type42_tables->len; i++) {
@@ -234,9 +249,9 @@ fu_redfish_plugin_discover_smbios_table(FuPlugin *plugin, GError **error)
 		if (!fu_firmware_parse_bytes(FU_FIRMWARE(smbios),
 					     type42_blob,
 					     0x0,
-					     FWUPD_INSTALL_FLAG_NO_SEARCH,
+					     FU_FIRMWARE_PARSE_FLAG_NO_SEARCH,
 					     error)) {
-			g_prefix_error(error, "failed to parse SMBIOS entry type 42: ");
+			g_prefix_error_literal(error, "failed to parse SMBIOS entry type 42: ");
 			return FALSE;
 		}
 		if (fu_redfish_smbios_get_interface_type(smbios) ==
@@ -604,7 +619,7 @@ fu_redfish_plugin_cleanup(FuPlugin *plugin,
 						     builder,
 						     FU_REDFISH_REQUEST_PERFORM_FLAG_NONE,
 						     error)) {
-			g_prefix_error(error, "failed to reset manager: ");
+			g_prefix_error_literal(error, "failed to reset manager: ");
 			return FALSE;
 		}
 	}
@@ -641,7 +656,7 @@ fu_redfish_plugin_cleanup(FuPlugin *plugin,
 				  FU_REDFISH_PLUGIN_CLEANUP_RETRIES_DELAY * 1000,
 				  self,
 				  error)) {
-		g_prefix_error(error, "manager failed to come back from setup: ");
+		g_prefix_error_literal(error, "manager failed to come back from setup: ");
 		return FALSE;
 	}
 	fu_progress_step_done(progress);
@@ -659,7 +674,7 @@ fu_redfish_plugin_cleanup(FuPlugin *plugin,
 				  FU_REDFISH_PLUGIN_CLEANUP_RETRIES_DELAY * 1000,
 				  self,
 				  error)) {
-		g_prefix_error(error, "manager failed to come back from coldplug: ");
+		g_prefix_error_literal(error, "manager failed to come back from coldplug: ");
 		return FALSE;
 	}
 	fu_progress_step_done(progress);
@@ -709,6 +724,7 @@ fu_redfish_plugin_constructed(GObject *obj)
 	self->backend = fu_redfish_backend_new(ctx);
 	fu_plugin_add_firmware_gtype(plugin, NULL, FU_TYPE_REDFISH_SMBIOS);
 	fu_plugin_add_flag(plugin, FWUPD_PLUGIN_FLAG_SECURE_CONFIG);
+	fu_plugin_add_device_gtype(plugin, FU_TYPE_REDFISH_HPE_DEVICE);	      /* coverage */
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_REDFISH_LEGACY_DEVICE);    /* coverage */
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_REDFISH_MULTIPART_DEVICE); /* coverage */
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_IPMI_DEVICE);	      /* coverage */
