@@ -370,7 +370,7 @@ fu_steelseries_fizz_ensure_children(FuSteelseriesFizz *self, GError **error)
 		return TRUE;
 
 	if (!fu_steelseries_fizz_get_paired_status(self, &status, error)) {
-		g_prefix_error(error, "failed to get paired status: ");
+		g_prefix_error_literal(error, "failed to get paired status: ");
 		return FALSE;
 	}
 
@@ -429,7 +429,7 @@ fu_steelseries_fizz_attach(FuDevice *device, FuProgress *progress, GError **erro
 				       FALSE,
 				       FU_STEELSERIES_FIZZ_RESET_MODE_NORMAL,
 				       &error_local))
-		g_warning("failed to reset: %s", error_local->message);
+		g_debug("failed to reset: %s", error_local->message);
 
 	fu_device_remove_flag(device, FWUPD_DEVICE_FLAG_IS_BOOTLOADER);
 	fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
@@ -464,11 +464,13 @@ fu_steelseries_fizz_setup(FuDevice *device, GError **error)
 	version =
 	    fu_steelseries_fizz_impl_get_version(FU_STEELSERIES_FIZZ_IMPL(proxy), FALSE, error);
 	if (version == NULL) {
-		g_prefix_error(error, "failed to get version: "); /* nocheck:set-version */
+		g_prefix_error_literal(error, "failed to get version: "); /* nocheck:set-version */
 		return FALSE;
 	}
 	fu_device_set_version(device, version);
 
+	/* read serial only for headset, since it is used to discover the same device attached
+	 * directly and via receiver in the same time */
 	if (!fu_device_has_private_flag(device, FU_STEELSERIES_DEVICE_FLAG_IS_RECEIVER)) {
 		/* direct connection */
 		serial = fu_steelseries_fizz_impl_get_serial(FU_STEELSERIES_FIZZ_IMPL(proxy),
@@ -639,7 +641,7 @@ fu_steelseries_fizz_read_firmware_fs(FuSteelseriesFizz *self,
 
 	fu_dump_raw(G_LOG_DOMAIN, "Firmware", buf, size);
 	blob = g_bytes_new_take(g_steal_pointer(&buf), size);
-	if (!fu_firmware_parse_bytes(firmware, blob, 0x0, FWUPD_INSTALL_FLAG_NO_SEARCH, error))
+	if (!fu_firmware_parse_bytes(firmware, blob, 0x0, FU_FIRMWARE_PARSE_FLAG_NO_SEARCH, error))
 		return NULL;
 
 	/* success */
@@ -700,6 +702,7 @@ static void
 fu_steelseries_fizz_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 1, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 80, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 1, "attach");
@@ -730,7 +733,6 @@ fu_steelseries_fizz_init(FuSteelseriesFizz *self)
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_STEELSERIES_DEVICE_FLAG_DETACH_BOOTLOADER);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_REPLUG_MATCH_GUID);
-	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_ONLY_WAIT_FOR_REPLUG);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_USE_PROXY_FOR_OPEN);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_REFCOUNTED_PROXY);
 	fu_device_add_protocol(FU_DEVICE(self), "com.steelseries.fizz");
