@@ -17,6 +17,11 @@
 #include "fu-synaptics-mst-firmware.h"
 #include "fu-synaptics-mst-struct.h"
 
+/*
+ * NOTE: DO NOT ALLOW ANY MORE MAGIC CONSTANTS IN THIS FILE
+ * nocheck:magic-defines=26
+ */
+
 #define FU_SYNAPTICS_MST_ID_CTRL_SIZE	 0x1000
 #define SYNAPTICS_UPDATE_ENUMERATE_TRIES 3
 
@@ -106,7 +111,7 @@ fu_synaptics_mst_device_init(FuSynapticsMstDevice *self)
 	fu_device_set_vendor(FU_DEVICE(self), "Synaptics");
 	fu_device_build_vendor_id_u16(FU_DEVICE(self), "DRM_DP_AUX_DEV", 0x06CB);
 	fu_device_set_summary(FU_DEVICE(self), "Multi-stream transport device");
-	fu_device_add_icon(FU_DEVICE(self), "video-display");
+	fu_device_add_icon(FU_DEVICE(self), FU_DEVICE_ICON_VIDEO_DISPLAY);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_TRIPLET);
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_SYNAPTICS_MST_DEVICE_FLAG_IGNORE_BOARD_ID);
@@ -194,7 +199,7 @@ fu_synaptics_mst_device_rc_send_command_and_wait_cb(FuDevice *device,
 				  sizeof(buf),
 				  FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 				  error)) {
-		g_prefix_error(error, "failed to read command: ");
+		g_prefix_error_literal(error, "failed to read command: ");
 		return FALSE;
 	}
 	if (buf[0] & 0x80) {
@@ -227,7 +232,7 @@ fu_synaptics_mst_device_rc_send_command_and_wait(FuSynapticsMstDevice *self,
 				   sizeof(buf),
 				   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 				   error)) {
-		g_prefix_error(error, "failed to write command: ");
+		g_prefix_error_literal(error, "failed to write command: ");
 		return FALSE;
 	}
 
@@ -238,12 +243,12 @@ fu_synaptics_mst_device_rc_send_command_and_wait(FuSynapticsMstDevice *self,
 				  100, /* ms */
 				  &helper,
 				  error)) {
-		g_prefix_error(error, "remote command failed: ");
+		g_prefix_error_literal(error, "remote command failed: ");
 		return FALSE;
 	}
 	if (helper.rc != FU_SYNAPTICS_MST_UPDC_RC_SUCCESS) {
 		if (!fu_synaptics_mst_device_rc_to_error(helper.rc, error)) {
-			g_prefix_error(error, "remote command failed: ");
+			g_prefix_error_literal(error, "remote command failed: ");
 			return FALSE;
 		}
 	}
@@ -284,7 +289,7 @@ fu_synaptics_mst_device_rc_set_command(FuSynapticsMstDevice *self,
 					   fu_chunk_get_data_sz(chk),
 					   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					   error)) {
-			g_prefix_error(error, "failure writing data register: ");
+			g_prefix_error_literal(error, "failure writing data register: ");
 			return FALSE;
 		}
 
@@ -296,7 +301,7 @@ fu_synaptics_mst_device_rc_set_command(FuSynapticsMstDevice *self,
 					   sizeof(buf2),
 					   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					   error)) {
-			g_prefix_error(error, "failure writing offset register: ");
+			g_prefix_error_literal(error, "failure writing offset register: ");
 			return FALSE;
 		}
 
@@ -308,7 +313,7 @@ fu_synaptics_mst_device_rc_set_command(FuSynapticsMstDevice *self,
 					   sizeof(buf2),
 					   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					   error)) {
-			g_prefix_error(error, "failure writing length register: ");
+			g_prefix_error_literal(error, "failure writing length register: ");
 			return FALSE;
 		}
 
@@ -360,7 +365,7 @@ fu_synaptics_mst_device_rc_get_command(FuSynapticsMstDevice *self,
 					   sizeof(buf2),
 					   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					   error)) {
-			g_prefix_error(error, "failed to write offset: ");
+			g_prefix_error_literal(error, "failed to write offset: ");
 			return FALSE;
 		}
 
@@ -372,7 +377,7 @@ fu_synaptics_mst_device_rc_get_command(FuSynapticsMstDevice *self,
 					   sizeof(buf2),
 					   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					   error)) {
-			g_prefix_error(error, "failed to write length: ");
+			g_prefix_error_literal(error, "failed to write length: ");
 			return FALSE;
 		}
 
@@ -390,7 +395,7 @@ fu_synaptics_mst_device_rc_get_command(FuSynapticsMstDevice *self,
 					  fu_chunk_get_data_sz(chk),
 					  FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					  error)) {
-			g_prefix_error(error, "failed to read data: ");
+			g_prefix_error_literal(error, "failed to read data: ");
 			return FALSE;
 		}
 	}
@@ -437,7 +442,7 @@ fu_synaptics_mst_device_enable_rc(FuSynapticsMstDevice *self, GError **error)
 		return TRUE;
 
 	if (!fu_synaptics_mst_device_disable_rc(self, error)) {
-		g_prefix_error(error, "failed to disable-to-enable: ");
+		g_prefix_error_literal(error, "failed to disable-to-enable: ");
 		return FALSE;
 	}
 	if (!fu_synaptics_mst_device_rc_set_command(self,
@@ -446,7 +451,7 @@ fu_synaptics_mst_device_enable_rc(FuSynapticsMstDevice *self, GError **error)
 						    (guint8 *)sc,
 						    strlen(sc),
 						    error)) {
-		g_prefix_error(error, "failed to enable remote control: ");
+		g_prefix_error_literal(error, "failed to enable remote control: ");
 		return FALSE;
 	}
 	return TRUE;
@@ -473,7 +478,7 @@ fu_synaptics_mst_device_rc_special_get_command(FuSynapticsMstDevice *self,
 						   cmd_datasz,
 						   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 						   error)) {
-				g_prefix_error(error, "Failed to write command data: ");
+				g_prefix_error_literal(error, "failed to write command data: ");
 				return FALSE;
 			}
 		}
@@ -486,7 +491,7 @@ fu_synaptics_mst_device_rc_special_get_command(FuSynapticsMstDevice *self,
 					   sizeof(buf2),
 					   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					   error)) {
-			g_prefix_error(error, "failed to write offset: ");
+			g_prefix_error_literal(error, "failed to write offset: ");
 			return FALSE;
 		}
 
@@ -498,7 +503,7 @@ fu_synaptics_mst_device_rc_special_get_command(FuSynapticsMstDevice *self,
 					   sizeof(buf2),
 					   FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					   error)) {
-			g_prefix_error(error, "failed to write length: ");
+			g_prefix_error_literal(error, "failed to write length: ");
 			return FALSE;
 		}
 	}
@@ -515,7 +520,7 @@ fu_synaptics_mst_device_rc_special_get_command(FuSynapticsMstDevice *self,
 					  bufsz,
 					  FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 					  error)) {
-			g_prefix_error(error, "failed to read length: ");
+			g_prefix_error_literal(error, "failed to read length: ");
 			return FALSE;
 		}
 	}
@@ -543,7 +548,7 @@ fu_synaptics_mst_device_get_flash_checksum(FuSynapticsMstDevice *self,
 		buf,
 		sizeof(buf),
 		error)) {
-		g_prefix_error(error, "failed to get flash checksum: ");
+		g_prefix_error_literal(error, "failed to get flash checksum: ");
 		return FALSE;
 	}
 
@@ -815,7 +820,7 @@ fu_synaptics_mst_device_get_active_bank_panamera(FuSynapticsMstDevice *self, GEr
 						    (guint8 *)buf,
 						    ((sizeof(buf) / sizeof(buf[0])) * 4),
 						    error)) {
-		g_prefix_error(error, "get active bank failed: ");
+		g_prefix_error_literal(error, "get active bank failed: ");
 		return FALSE;
 	}
 	if ((buf[0] & BIT(7)) || (buf[0] & BIT(30)))
@@ -875,7 +880,7 @@ fu_synaptics_mst_device_update_panamera_firmware_cb(FuDevice *device,
 				fu_chunk_get_data(chk),
 				fu_chunk_get_data_sz(chk),
 				error)) {
-				g_prefix_error(error, "firmware write failed: ");
+				g_prefix_error_literal(error, "firmware write failed: ");
 				return FALSE;
 			}
 		}
@@ -895,7 +900,7 @@ fu_synaptics_mst_device_update_panamera_firmware_cb(FuDevice *device,
 			buf,
 			sizeof(buf),
 			error)) {
-			g_prefix_error(error, "failed to get flash checksum: ");
+			g_prefix_error_literal(error, "failed to get flash checksum: ");
 			return FALSE;
 		}
 		flash_checksum = fu_memread_uint32(buf, G_LITTLE_ENDIAN);
@@ -948,7 +953,7 @@ fu_synaptics_mst_device_update_panamera_set_new_valid_cb(FuDevice *device,
 		buf,
 		sizeof(buf),
 		error)) {
-		g_prefix_error(error, "failed to write tag: ");
+		g_prefix_error_literal(error, "failed to write tag: ");
 		return FALSE;
 	}
 	fu_device_sleep(FU_DEVICE(self), 1); /* ms */
@@ -959,7 +964,7 @@ fu_synaptics_mst_device_update_panamera_set_new_valid_cb(FuDevice *device,
 		buf_verify,
 		sizeof(buf_verify),
 		error)) {
-		g_prefix_error(error, "failed to read tag: ");
+		g_prefix_error_literal(error, "failed to read tag: ");
 		return FALSE;
 	}
 	if (memcmp(buf, buf_verify, sizeof(buf)) != 0) {
@@ -1004,7 +1009,7 @@ fu_synaptics_mst_device_update_panamera_set_old_invalid_cb(FuDevice *device,
 		&checksum_nul,
 		sizeof(checksum_nul),
 		error)) {
-		g_prefix_error(error, "failed to clear CRC: ");
+		g_prefix_error_literal(error, "failed to clear CRC: ");
 		return FALSE;
 	}
 	if (!fu_synaptics_mst_device_rc_get_command(
@@ -1014,7 +1019,7 @@ fu_synaptics_mst_device_update_panamera_set_old_invalid_cb(FuDevice *device,
 		&checksum_tmp,
 		sizeof(checksum_tmp),
 		error)) {
-		g_prefix_error(error, "failed to read CRC from flash: ");
+		g_prefix_error_literal(error, "failed to read CRC from flash: ");
 		return FALSE;
 	}
 	if (checksum_tmp != checksum_nul) {
@@ -1106,7 +1111,7 @@ fu_synaptics_mst_device_update_panamera_firmware(FuSynapticsMstDevice *self,
 		&checksum8,
 		sizeof(checksum8),
 		error)) {
-		g_prefix_error(error, "failed to read tag from flash: ");
+		g_prefix_error_literal(error, "failed to read tag from flash: ");
 		return FALSE;
 	}
 	helper->checksum = checksum8;
@@ -1133,7 +1138,7 @@ fu_synaptics_mst_device_panamera_prepare_write(FuSynapticsMstDevice *self, GErro
 						    (guint8 *)buf,
 						    4,
 						    error)) {
-		g_prefix_error(error, "ESM disable failed: ");
+		g_prefix_error_literal(error, "ESM disable failed: ");
 		return FALSE;
 	}
 
@@ -1147,7 +1152,7 @@ fu_synaptics_mst_device_panamera_prepare_write(FuSynapticsMstDevice *self, GErro
 						    (guint8 *)buf,
 						    ((sizeof(buf) / sizeof(buf[0])) * 4),
 						    error)) {
-		g_prefix_error(error, "quad query failed: ");
+		g_prefix_error_literal(error, "quad query failed: ");
 		return FALSE;
 	}
 
@@ -1158,7 +1163,7 @@ fu_synaptics_mst_device_panamera_prepare_write(FuSynapticsMstDevice *self, GErro
 						    (guint8 *)buf,
 						    4,
 						    error)) {
-		g_prefix_error(error, "quad disable failed: ");
+		g_prefix_error_literal(error, "quad disable failed: ");
 		return FALSE;
 	}
 
@@ -1169,7 +1174,7 @@ fu_synaptics_mst_device_panamera_prepare_write(FuSynapticsMstDevice *self, GErro
 						    (guint8 *)buf,
 						    4,
 						    error)) {
-		g_prefix_error(error, "HDCP query failed: ");
+		g_prefix_error_literal(error, "HDCP query failed: ");
 		return FALSE;
 	}
 
@@ -1180,7 +1185,7 @@ fu_synaptics_mst_device_panamera_prepare_write(FuSynapticsMstDevice *self, GErro
 						    (guint8 *)buf,
 						    4,
 						    error)) {
-		g_prefix_error(error, "HDCP disable failed: ");
+		g_prefix_error_literal(error, "HDCP disable failed: ");
 		return FALSE;
 	}
 
@@ -1250,7 +1255,7 @@ fu_synaptics_mst_device_update_firmware_cb(FuDevice *device, gpointer user_data,
 		buf,
 		sizeof(buf),
 		error)) {
-		g_prefix_error(error, "Failed to get flash checksum: ");
+		g_prefix_error_literal(error, "failed to get flash checksum: ");
 		return FALSE;
 	}
 	flash_checksum = fu_memread_uint32(buf, G_LITTLE_ENDIAN);
@@ -1291,10 +1296,10 @@ fu_synaptics_mst_device_update_firmware(FuSynapticsMstDevice *self,
 		fw_size = CARRERA_FIRMWARE_SIZE;
 		break;
 	default:
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOT_SUPPORTED,
-			    "Unsupported chip family");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "unsupported chip family");
 		return FALSE;
 	}
 
@@ -1322,7 +1327,7 @@ fu_synaptics_mst_device_update_firmware(FuSynapticsMstDevice *self,
 						    NULL,
 						    0,
 						    error)) {
-		g_prefix_error(error, "active firmware failed: ");
+		g_prefix_error_literal(error, "active firmware failed: ");
 		return FALSE;
 	}
 
@@ -1350,10 +1355,10 @@ fu_synaptics_mst_device_restart(FuSynapticsMstDevice *self, GError **error)
 		offset = 0x2020A024;
 		break;
 	default:
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOT_SUPPORTED,
-			    "Unsupported chip family");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "unsupported chip family");
 		return FALSE;
 	}
 	/* issue the reboot command, ignore return code (triggers before returning) */
@@ -1468,21 +1473,21 @@ fu_synaptics_mst_device_write_firmware(FuDevice *device,
 									fw,
 									progress,
 									error)) {
-			g_prefix_error(error, "Firmware update failed: ");
+			g_prefix_error_literal(error, "firmware update failed: ");
 			return FALSE;
 		}
 		break;
 	case FU_SYNAPTICS_MST_FAMILY_PANAMERA:
 		if (!fu_synaptics_mst_device_panamera_prepare_write(self, error)) {
-			g_prefix_error(error, "Failed to prepare for write: ");
+			g_prefix_error_literal(error, "failed to prepare for write: ");
 			return FALSE;
 		}
 		if (!fu_synaptics_mst_device_update_esm(self, fw, progress, error)) {
-			g_prefix_error(error, "ESM update failed: ");
+			g_prefix_error_literal(error, "ESM update failed: ");
 			return FALSE;
 		}
 		if (!fu_synaptics_mst_device_update_panamera_firmware(self, fw, progress, error)) {
-			g_prefix_error(error, "Firmware update failed: ");
+			g_prefix_error_literal(error, "firmware update failed: ");
 			return FALSE;
 		}
 		break;
@@ -1490,15 +1495,15 @@ fu_synaptics_mst_device_write_firmware(FuDevice *device,
 	case FU_SYNAPTICS_MST_FAMILY_SPYDER:
 	case FU_SYNAPTICS_MST_FAMILY_CARRERA:
 		if (!fu_synaptics_mst_device_update_firmware(self, fw, progress, error)) {
-			g_prefix_error(error, "Firmware update failed: ");
+			g_prefix_error_literal(error, "firmware update failed: ");
 			return FALSE;
 		}
 		break;
 	default:
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOT_SUPPORTED,
-			    "Unsupported chip family");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "unsupported chip family");
 		return FALSE;
 	}
 	fu_progress_step_done(progress);
@@ -1567,7 +1572,7 @@ fu_synaptics_mst_device_ensure_board_id(FuSynapticsMstDevice *self, GError **err
 							    buf,
 							    sizeof(buf),
 							    error)) {
-			g_prefix_error(error, "RC command failed: ");
+			g_prefix_error_literal(error, "RC command failed: ");
 			return FALSE;
 		}
 		if (!fu_memread_uint16_safe(buf,
@@ -1592,10 +1597,10 @@ fu_synaptics_mst_device_ensure_board_id(FuSynapticsMstDevice *self, GError **err
 			offset = (gint)ADDR_MEMORY_CUSTOMER_ID_SPYDER;
 			break;
 		default:
-			g_set_error(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_NOT_SUPPORTED,
-				    "Unsupported chip family");
+			g_set_error_literal(error,
+					    FWUPD_ERROR,
+					    FWUPD_ERROR_NOT_SUPPORTED,
+					    "unsupported chip family");
 			return FALSE;
 		}
 
@@ -1606,7 +1611,7 @@ fu_synaptics_mst_device_ensure_board_id(FuSynapticsMstDevice *self, GError **err
 			buf,
 			sizeof(buf),
 			error)) {
-			g_prefix_error(error, "memory query failed: ");
+			g_prefix_error_literal(error, "memory query failed: ");
 			return FALSE;
 		}
 		if (!fu_memread_uint16_safe(buf,
@@ -1647,7 +1652,7 @@ fu_synaptics_mst_device_setup(FuDevice *device, GError **error)
 				  sizeof(rc_cap),
 				  FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 				  error)) {
-		g_prefix_error(error, "failed to read remote control capabilities: ");
+		g_prefix_error_literal(error, "failed to read remote control capabilities: ");
 		return FALSE;
 	}
 	if ((rc_cap & 0x04) == 0) {
@@ -1669,9 +1674,9 @@ fu_synaptics_mst_device_setup(FuDevice *device, GError **error)
 					    FWUPD_ERROR,
 					    FWUPD_ERROR_NOT_SUPPORTED,
 					    "downstream endpoint not supported");
-		} else {
-			g_propagate_error(error, g_steal_pointer(&error_local));
+			return FALSE;
 		}
+		g_propagate_error(error, g_steal_pointer(&error_local));
 		return FALSE;
 	}
 
@@ -1682,7 +1687,7 @@ fu_synaptics_mst_device_setup(FuDevice *device, GError **error)
 				  sizeof(buf_ver),
 				  FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 				  error)) {
-		g_prefix_error(error, "failed to read firmware version: ");
+		g_prefix_error_literal(error, "failed to read firmware version: ");
 		return FALSE;
 	}
 
@@ -1696,7 +1701,7 @@ fu_synaptics_mst_device_setup(FuDevice *device, GError **error)
 				  sizeof(buf_cid),
 				  FU_SYNAPTICS_MST_DEVICE_READ_TIMEOUT,
 				  error)) {
-		g_prefix_error(error, "failed to read chip id: ");
+		g_prefix_error_literal(error, "failed to read chip id: ");
 		return FALSE;
 	}
 	self->chip_id = fu_memread_uint16(buf_cid, G_BIG_ENDIAN);
