@@ -36,6 +36,12 @@ struct _FuUefiCapsulePlugin {
 
 G_DEFINE_TYPE(FuUefiCapsulePlugin, fu_uefi_capsule_plugin, FU_TYPE_PLUGIN)
 
+FuBackend *
+fu_uefi_capsule_plugin_get_backend(FuUefiCapsulePlugin *self)
+{
+	return self->backend;
+}
+
 static void
 fu_uefi_capsule_plugin_to_string(FuPlugin *plugin, guint idt, GString *str)
 {
@@ -53,7 +59,7 @@ fu_uefi_capsule_plugin_to_string(FuPlugin *plugin, guint idt, GString *str)
 }
 
 static gboolean
-fu_uefi_capsule_plugin_fwupd_efi_parse(FuUefiCapsulePlugin *self, GError **error)
+fu_uefi_capsule_plugin_fwupd_efi_parse_fallback(FuUefiCapsulePlugin *self, GError **error)
 {
 	FuContext *ctx = fu_plugin_get_context(FU_PLUGIN(self));
 	const guint8 needle[] = "f\0w\0u\0p\0d\0-\0e\0f\0i\0 \0v\0e\0r\0s\0i\0o\0n\0 ";
@@ -94,6 +100,64 @@ fu_uefi_capsule_plugin_fwupd_efi_parse(FuUefiCapsulePlugin *self, GError **error
 	return TRUE;
 }
 
+static void
+fu_uefi_capsule_plugin_fwupd_efi_add_sbom(FuUefiCapsulePlugin *self,
+					  const gchar *product,
+					  const gchar *version)
+{
+	FuContext *ctx = fu_plugin_get_context(FU_PLUGIN(self));
+	if (g_strcmp0(product, "fwupdx64") == 0) {
+		fu_context_add_runtime_version(ctx, "org.freedesktop.fwupd-efi", version);
+		return;
+	}
+	if (g_strcmp0(product, "gnu-efi") == 0) {
+		fu_context_add_runtime_version(ctx, "com.github.ncroxon.gnu-efi", version);
+		return;
+	}
+}
+
+static gboolean
+fu_uefi_capsule_plugin_fwupd_efi_parse_sbom(FuUefiCapsulePlugin *self, GError **error)
+{
+	g_autoptr(FuFirmware) fw = fu_pefile_firmware_new();
+	g_autoptr(FuFirmware) fw_sbom = NULL;
+	g_autoptr(GPtrArray) fw_coswids = NULL;
+
+	if (!fu_firmware_parse_file(fw, self->fwupd_efi_file, FU_FIRMWARE_PARSE_FLAG_NONE, error))
+		return FALSE;
+	fw_sbom = fu_firmware_get_image_by_id(fw, ".sbom", error);
+	if (fw_sbom == NULL)
+		return FALSE;
+	fw_coswids = fu_firmware_get_images(fw_sbom);
+	for (guint i = 0; i < fw_coswids->len; i++) {
+		FuFirmware *fw_coswid = g_ptr_array_index(fw_coswids, i);
+		if (!FU_IS_COSWID_FIRMWARE(fw_coswid))
+			continue;
+		fu_uefi_capsule_plugin_fwupd_efi_add_sbom(
+		    self,
+		    fu_coswid_firmware_get_product(FU_COSWID_FIRMWARE(fw_coswid)),
+		    fu_firmware_get_version(fw_coswid));
+	}
+
+	/* success */
+	return TRUE;
+}
+
+static gboolean
+fu_uefi_capsule_plugin_fwupd_efi_parse(FuUefiCapsulePlugin *self, GError **error)
+{
+	g_autoptr(GError) error_local = NULL;
+
+	/* try parsing the SBOM, then fall back to a well-known token */
+	if (!fu_uefi_capsule_plugin_fwupd_efi_parse_sbom(self, &error_local)) {
+		g_debug("failed to parse SBOM, using fallback: %s", error_local->message);
+		return fu_uefi_capsule_plugin_fwupd_efi_parse_fallback(self, error);
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static void
 fu_uefi_capsule_plugin_fwupd_efi_changed_cb(GFileMonitor *monitor,
 					    GFile *file,
@@ -269,6 +333,7 @@ fu_uefi_capsule_plugin_add_security_attrs(FuPlugin *plugin, FuSecurityAttrs *att
 	fu_uefi_capsule_plugin_add_security_attrs_bootservices(plugin, attrs);
 }
 
+#ifdef FWUPD_UEFI_CAPSULE_SPLASH_ENABLED
 static GBytes *
 fu_uefi_capsule_plugin_get_splash_data(guint width, guint height, GError **error)
 {
@@ -333,7 +398,6 @@ fu_uefi_capsule_plugin_write_splash_data(FuUefiCapsulePlugin *self,
 	g_autoptr(FuBitmapImage) bmp_image = fu_bitmap_image_new();
 	g_autoptr(GByteArray) st_cap = fu_struct_efi_capsule_header_new();
 	g_autoptr(GByteArray) st_uxh = fu_struct_efi_ux_capsule_header_new();
-	g_autoptr(GFile) ofile = NULL;
 	g_autoptr(GOutputStream) ostream = NULL;
 
 	/* get screen dimensions */
@@ -342,7 +406,7 @@ fu_uefi_capsule_plugin_write_splash_data(FuUefiCapsulePlugin *self,
 				     0x0,
 				     FU_FIRMWARE_PARSE_FLAG_NONE,
 				     error)) {
-		g_prefix_error(error, "splash invalid: ");
+		g_prefix_error_literal(error, "splash invalid: ");
 		return FALSE;
 	}
 	width = fu_bitmap_image_get_width(bmp_image);
@@ -355,9 +419,7 @@ fu_uefi_capsule_plugin_write_splash_data(FuUefiCapsulePlugin *self,
 	fn = g_build_filename(esp_path, capsule_path, NULL);
 	if (!fu_path_mkdir_parent(fn, error))
 		return FALSE;
-	ofile = g_file_new_for_path(fn);
-	ostream =
-	    G_OUTPUT_STREAM(g_file_replace(ofile, NULL, FALSE, G_FILE_CREATE_NONE, NULL, error));
+	ostream = fu_output_stream_from_path(fn, error);
 	if (ostream == NULL)
 		return FALSE;
 
@@ -398,8 +460,7 @@ fu_uefi_capsule_plugin_write_splash_data(FuUefiCapsulePlugin *self,
 	size = g_output_stream_write(ostream, st_uxh->data, st_uxh->len, NULL, error);
 	if (size < 0)
 		return FALSE;
-	size = g_output_stream_write_bytes(ostream, blob, NULL, error);
-	if (size < 0)
+	if (!fu_output_stream_write_bytes(ostream, blob, NULL, error))
 		return FALSE;
 
 	/* write display capsule location as UPDATE_INFO */
@@ -490,6 +551,7 @@ fu_uefi_capsule_plugin_update_splash(FuPlugin *plugin, FuDevice *device, GError
 	/* perform the upload */
 	return fu_uefi_capsule_plugin_write_splash_data(self, device, image_bmp, error);
 }
+#endif // FWUPD_UEFI_CAPSULE_SPLASH_ENABLED
 
 static gboolean
 fu_uefi_capsule_plugin_write_firmware(FuPlugin *plugin,
@@ -529,8 +591,10 @@ fu_uefi_capsule_plugin_write_firmware(FuPlugin *plugin,
 
 	/* perform the update */
 	fu_progress_set_status(progress, FWUPD_STATUS_SCHEDULING);
+#ifdef FWUPD_UEFI_CAPSULE_SPLASH_ENABLED
 	if (!fu_uefi_capsule_plugin_update_splash(plugin, device, &error_splash))
 		g_info("failed to upload UEFI UX capsule text: %s", error_splash->message);
+#endif
 
 	return fu_device_write_firmware(device, firmware, progress, flags, error);
 }
@@ -789,7 +853,7 @@ fu_uefi_capsule_plugin_ensure_screen_size_config(FuUefiCapsulePlugin *self, GErr
 				 G_MAXUINT32,
 				 FU_INTEGER_BASE_AUTO,
 				 error)) {
-			g_prefix_error(error, "failed to parse ScreenWidth: ");
+			g_prefix_error_literal(error, "failed to parse ScreenWidth: ");
 			return FALSE;
 		}
 		self->screen_width = (guint32)tmp64;
@@ -803,7 +867,7 @@ fu_uefi_capsule_plugin_ensure_screen_size_config(FuUefiCapsulePlugin *self, GErr
 				 G_MAXUINT32,
 				 FU_INTEGER_BASE_AUTO,
 				 error)) {
-			g_prefix_error(error, "failed to parse ScreenHeight: ");
+			g_prefix_error_literal(error, "failed to parse ScreenHeight: ");
 			return FALSE;
 		}
 		self->screen_height = (guint32)tmp64;
@@ -842,8 +906,6 @@ fu_uefi_capsule_plugin_startup(FuPlugin *plugin, FuProgress *progress, GError **
 	FuUefiCapsulePlugin *self = FU_UEFI_CAPSULE_PLUGIN(plugin);
 	FuContext *ctx = fu_plugin_get_context(plugin);
 	FuEfivars *efivars = fu_context_get_efivars(ctx);
-	guint64 nvram_total;
-	g_autofree gchar *nvram_total_str = NULL;
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GError) error_acpi_uefi = NULL;
 
@@ -888,11 +950,6 @@ fu_uefi_capsule_plugin_startup(FuPlugin *plugin, FuProgress *progress, GError **
 	/* are the EFI dirs set up so we can update each device */
 	if (!fu_efivars_supported(efivars, error))
 		return FALSE;
-	nvram_total = fu_efivars_space_used(efivars, error);
-	if (nvram_total == G_MAXUINT64)
-		return FALSE;
-	nvram_total_str = g_strdup_printf("%" G_GUINT64_FORMAT, nvram_total);
-	fu_plugin_add_report_metadata(plugin, "EfivarsNvramUsed", nvram_total_str);
 
 	/* we use this both for quirking the CoD implementation sanity and the CoD filename */
 	self->acpi_uefi = fu_uefi_capsule_plugin_parse_acpi_uefi(self, &error_acpi_uefi);
@@ -971,7 +1028,7 @@ fu_uefi_capsule_plugin_check_cod_support(FuUefiCapsulePlugin *self, GError **err
 				 &bufsz,
 				 NULL,
 				 error)) {
-		g_prefix_error(error, "failed to read EFI variable: ");
+		g_prefix_error_literal(error, "failed to read EFI variable: ");
 		return FALSE;
 	}
 	if (!fu_memread_uint64_safe(buf, bufsz, 0x0, &value, G_LITTLE_ENDIAN, error))
@@ -1017,7 +1074,6 @@ fu_uefi_capsule_plugin_coldplug(FuPlugin *plugin, FuProgress *progress, GError *
 	FuUefiCapsulePlugin *self = FU_UEFI_CAPSULE_PLUGIN(plugin);
 	FuContext *ctx = fu_plugin_get_context(plugin);
 	const gchar *str;
-	gboolean has_fde = FALSE;
 	gboolean bootloader_supports_fwupd = fu_uefi_capsule_plugin_bootloader_supports_fwupd(ctx);
 	g_autoptr(GError) error_fde = NULL;
 	g_autoptr(GError) error_local = NULL;
@@ -1026,13 +1082,13 @@ fu_uefi_capsule_plugin_coldplug(FuPlugin *plugin, FuProgress *progress, GError *
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 1, "check-cod");
-	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 8, "check-bitlocker");
-	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 64, "coldplug");
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 72, "coldplug");
 	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 26, "add-devices");
 	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 1, "setup-bgrt");
 
 	/* firmware may lie */
-	if (!fu_plugin_get_config_value_boolean(plugin, "DisableCapsuleUpdateOnDisk")) {
+	if (!fu_plugin_get_config_value_boolean(plugin, "DisableCapsuleUpdateOnDisk") &&
+	    !fu_context_has_hwid_flag(ctx, "no-capsule-on-disk")) {
 		g_autoptr(GError) error_cod = NULL;
 		if (!fu_uefi_capsule_plugin_check_cod_support(self, &error_cod)) {
 			g_debug("not using CapsuleOnDisk support: %s", error_cod->message);
@@ -1044,11 +1100,6 @@ fu_uefi_capsule_plugin_coldplug(FuPlugin *plugin, FuProgress *progress, GError *
 	}
 	fu_progress_step_done(progress);
 
-	/*  warn the user that BitLocker might ask for recovery key after fw update */
-	if (fu_context_has_flag(ctx, FU_CONTEXT_FLAG_FDE_BITLOCKER))
-		has_fde = TRUE;
-	fu_progress_step_done(progress);
-
 	/* add each device */
 	if (!fu_backend_coldplug(self->backend, fu_progress_get_child(progress), error))
 		return FALSE;
@@ -1079,8 +1130,7 @@ fu_uefi_capsule_plugin_coldplug(FuPlugin *plugin, FuProgress *progress, GError *
 
 		/* system firmware "BIOS" can change the PCRx registers */
 		if (fu_uefi_capsule_device_get_kind(dev) ==
-			FU_UEFI_CAPSULE_DEVICE_KIND_SYSTEM_FIRMWARE &&
-		    has_fde)
+		    FU_UEFI_CAPSULE_DEVICE_KIND_SYSTEM_FIRMWARE)
 			fu_device_add_flag(FU_DEVICE(dev), FWUPD_DEVICE_FLAG_AFFECTS_FDE);
 
 		/* load all configuration variables */
@@ -1103,6 +1153,9 @@ fu_uefi_capsule_plugin_coldplug(FuPlugin *plugin, FuProgress *progress, GError *
 	str = fu_uefi_bgrt_get_supported(self->bgrt) ? "Enabled" : "Disabled";
 	g_info("UX capsule support : %s", str);
 	fu_plugin_add_report_metadata(plugin, "UEFIUXCapsule", str);
+	str = bootloader_supports_fwupd ? "True" : "False";
+	g_info("Bootloader supports fwupd: %s", str);
+	fu_plugin_add_report_metadata(plugin, "BootloaderSupportsFwupd", str);
 	fu_progress_step_done(progress);
 
 	return TRUE;
