@@ -52,7 +52,7 @@ fu_vli_usbhub_msp430_device_i2c_read(FuVliUsbhubDevice *self,
 					    FU_VLI_DEVICE_TIMEOUT,
 					    NULL,
 					    error)) {
-		g_prefix_error(error, "failed to read I2C: ");
+		g_prefix_error_literal(error, "failed to read I2C: ");
 		return FALSE;
 	}
 	fu_dump_raw(G_LOG_DOMAIN, "I2cReadData", buf, bufsz);
@@ -123,7 +123,7 @@ fu_vli_usbhub_msp430_device_setup(FuDevice *device, GError **error)
 						  buf,
 						  sizeof(buf),
 						  error)) {
-		g_prefix_error(error, "failed to read versions: ");
+		g_prefix_error_literal(error, "failed to read versions: ");
 		return FALSE;
 	}
 	if ((buf[0] == 0x00 && buf[1] == 0x00 && buf[2] == 0x00) ||
@@ -164,7 +164,7 @@ fu_vli_usbhub_msp430_device_detach(FuDevice *device, FuProgress *progress, GErro
 
 	/* check the device came back */
 	if (!fu_vli_usbhub_msp430_device_i2c_read_status(parent, &status, error)) {
-		g_prefix_error(error, "device did not come back after detach: ");
+		g_prefix_error_literal(error, "device did not come back after detach: ");
 		return FALSE;
 	}
 	return fu_vli_usbhub_i2c_check_status(status, error);
@@ -319,6 +319,7 @@ static void
 fu_vli_usbhub_msp430_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 13, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 85, "attach");
@@ -328,7 +329,7 @@ fu_vli_usbhub_msp430_device_set_progress(FuDevice *self, FuProgress *progress)
 static void
 fu_vli_usbhub_msp430_device_init(FuVliUsbhubMsp430Device *self)
 {
-	fu_device_add_icon(FU_DEVICE(self), "usb-hub");
+	fu_device_add_icon(FU_DEVICE(self), FU_DEVICE_ICON_USB_HUB);
 	fu_device_add_protocol(FU_DEVICE(self), "com.vli.i2c");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
