@@ -505,7 +505,7 @@ fu_wac_device_write_firmware(FuDevice *device,
 		blob_tmp = fu_firmware_write_chunk(img, fd->start_addr, fd->block_sz, NULL);
 		if (blob_tmp == NULL)
 			break;
-		blob_block = fu_bytes_pad(blob_tmp, fd->block_sz);
+		blob_block = fu_bytes_pad(blob_tmp, fd->block_sz, 0xFF);
 		g_hash_table_insert(fd_blobs, fd, blob_block);
 	}
 
@@ -578,10 +578,10 @@ fu_wac_device_write_firmware(FuDevice *device,
 
 	/* check at least one block was written */
 	if (blocks_done == 0) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_INTERNAL,
-			    "empty firmware image or all blocks write-protected");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INTERNAL,
+				    "empty firmware image or all blocks write-protected");
 		return FALSE;
 	}
 
@@ -654,7 +654,8 @@ fu_wac_device_add_modules_bluetooth(FuWacDevice *self, GError **error)
 						      sizeof(buf),
 						      FU_HID_DEVICE_FLAG_NONE,
 						      error)) {
-			g_prefix_error(error, "Failed to get GetFirmwareVersionBluetooth: ");
+			g_prefix_error_literal(error,
+					       "failed to get GetFirmwareVersionBluetooth: ");
 			return FALSE;
 		}
 		if (!fu_memread_uint16_safe(buf, sizeof(buf), 1, &fw_ver, G_LITTLE_ENDIAN, error))
@@ -706,7 +707,7 @@ fu_wac_device_add_modules_cb(FuDevice *device, gpointer user_data, GError **erro
 					      sizeof(buf),
 					      FU_HID_DEVICE_FLAG_NONE,
 					      error)) {
-		g_prefix_error(error, "failed to get DeviceFirmwareDescriptor: ");
+		g_prefix_error_literal(error, "failed to get DeviceFirmwareDescriptor: ");
 		return FALSE;
 	}
 
@@ -930,7 +931,7 @@ fu_wac_device_close(FuDevice *device, GError **error)
 					     0x00, /* HID */
 					     FU_USB_DEVICE_CLAIM_FLAG_KERNEL_DRIVER,
 					     error)) {
-		g_prefix_error(error, "failed to re-attach interface: ");
+		g_prefix_error_literal(error, "failed to re-attach interface: ");
 		return FALSE;
 	}
 
@@ -949,6 +950,7 @@ static void
 fu_wac_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 98, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "attach");
@@ -972,7 +974,7 @@ fu_wac_device_init(FuWacDevice *self)
 	self->configuration = 0xffff;
 	self->firmware_index = 0xffff;
 	fu_device_add_protocol(FU_DEVICE(self), "com.wacom.usb");
-	fu_device_add_icon(FU_DEVICE(self), "input-tablet");
+	fu_device_add_icon(FU_DEVICE(self), FU_DEVICE_ICON_INPUT_TABLET);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_MD_SET_FLAGS);
