@@ -235,7 +235,8 @@ fu_cabinet_parse_release(FuCabinet *self, XbNode *release, GError **error)
 		results = jcat_context_verify_target(self->jcat_context,
 						     item_target,
 						     item,
-						     JCAT_VERIFY_FLAG_REQUIRE_CHECKSUM |
+						     JCAT_VERIFY_FLAG_DISABLE_TIME_CHECKS |
+							 JCAT_VERIFY_FLAG_REQUIRE_CHECKSUM |
 							 JCAT_VERIFY_FLAG_REQUIRE_SIGNATURE,
 						     &error_local);
 		if (results == NULL) {
@@ -258,7 +259,8 @@ fu_cabinet_parse_release(FuCabinet *self, XbNode *release, GError **error)
 		results = jcat_context_verify_item(self->jcat_context,
 						   blob,
 						   item,
-						   JCAT_VERIFY_FLAG_REQUIRE_CHECKSUM |
+						   JCAT_VERIFY_FLAG_DISABLE_TIME_CHECKS |
+						       JCAT_VERIFY_FLAG_REQUIRE_CHECKSUM |
 						       JCAT_VERIFY_FLAG_REQUIRE_SIGNATURE,
 						   &error_local);
 		if (results == NULL) {
@@ -291,11 +293,13 @@ fu_cabinet_parse_release(FuCabinet *self, XbNode *release, GError **error)
 			if (data_sig == NULL)
 				return FALSE;
 			jcat_blob = jcat_blob_new(JCAT_BLOB_KIND_GPG, data_sig);
-			jcat_result = jcat_context_verify_blob(self->jcat_context,
-							       blob,
-							       jcat_blob,
-							       JCAT_VERIFY_FLAG_REQUIRE_SIGNATURE,
-							       &error_local);
+			jcat_result =
+			    jcat_context_verify_blob(self->jcat_context,
+						     blob,
+						     jcat_blob,
+						     JCAT_VERIFY_FLAG_DISABLE_TIME_CHECKS |
+							 JCAT_VERIFY_FLAG_REQUIRE_SIGNATURE,
+						     &error_local);
 			if (jcat_result == NULL) {
 				g_info("failed to verify payload %s using detached: %s",
 				       basename,
@@ -568,7 +572,7 @@ fu_cabinet_build_jcat_folder(FuCabinet *self, FuFirmware *img, GError **error)
 					     JCAT_IMPORT_FLAG_NONE,
 					     NULL,
 					     error)) {
-			g_prefix_error(error, "failed to import JCat stream: ");
+			g_prefix_error_literal(error, "failed to import JCat stream: ");
 			return FALSE;
 		}
 	}
@@ -602,6 +606,7 @@ fu_cabinet_build_silo(FuCabinet *self, GError **error)
 	g_autoptr(XbBuilderFixup) fixup2 = NULL;
 	g_autoptr(XbBuilderFixup) fixup3 = NULL;
 	g_autoptr(XbBuilderFixup) fixup4 = NULL;
+	g_autoptr(XbNode) guid1 = NULL;
 
 	/* verbose profiling */
 	if (g_getenv("FWUPD_XMLB_VERBOSE") != NULL) {
@@ -655,20 +660,43 @@ fu_cabinet_build_silo(FuCabinet *self, GError **error)
 	/* did we get any valid files */
 	self->silo =
 	    xb_builder_compile(self->builder, XB_BUILDER_COMPILE_FLAG_SINGLE_ROOT, NULL, error);
-	if (self->silo == NULL)
+	if (self->silo == NULL) {
+		fwupd_error_convert(error);
 		return FALSE;
+	}
+
+	/* verify there's at least one GUID */
+	guid1 = xb_silo_query_first(self->silo,
+				    "components/component[@type='firmware']/"
+				    "provides/firmware[@type='flashed']",
+				    error);
+	if (guid1 == NULL) {
+		fwupd_error_convert(error);
+		return FALSE;
+	}
+	if (xb_node_get_text(guid1) == NULL) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INVALID_FILE,
+				    "no <firmware type='flashed'> data");
+		return FALSE;
+	}
 
 	/* build the index */
 	if (!xb_silo_query_build_index(self->silo,
 				       "components/component[@type='firmware']/provides/firmware",
 				       "type",
-				       error))
+				       error)) {
+		fwupd_error_convert(error);
 		return FALSE;
+	}
 	if (!xb_silo_query_build_index(self->silo,
 				       "components/component[@type='firmware']/provides/firmware",
 				       NULL,
-				       error))
+				       error)) {
+		fwupd_error_convert(error);
 		return FALSE;
+	}
 
 	/* success */
 	return TRUE;
@@ -677,7 +705,7 @@ fu_cabinet_build_silo(FuCabinet *self, GError **error)
 static gboolean
 fu_cabinet_sign_filename(FuCabinet *self,
 			 const gchar *filename,
-			 JcatEngine *jcat_engine,
+			 JcatContext *jcat_context,
 			 JcatFile *jcat_file,
 			 GBytes *cert,
 			 GBytes *privkey,
@@ -685,7 +713,10 @@ fu_cabinet_sign_filename(FuCabinet *self,
 {
 	g_autoptr(FuFirmware) img = NULL;
 	g_autoptr(GBytes) source_blob = NULL;
-	g_autoptr(JcatBlob) jcat_blob = NULL;
+	g_autoptr(JcatBlob) jcat_blob_csum = NULL;
+	g_autoptr(JcatBlob) jcat_blob_sig = NULL;
+	g_autoptr(JcatEngine) jcat_engine_csum = NULL;
+	g_autoptr(JcatEngine) jcat_engine_sig = NULL;
 	g_autoptr(JcatItem) jcat_item = NULL;
 
 	/* sign the file using the engine */
@@ -700,15 +731,31 @@ fu_cabinet_sign_filename(FuCabinet *self,
 		jcat_item = jcat_item_new(filename);
 		jcat_file_add_item(jcat_file, jcat_item);
 	}
-	jcat_blob = jcat_engine_pubkey_sign(jcat_engine,
-					    source_blob,
-					    cert,
-					    privkey,
-					    JCAT_SIGN_FLAG_ADD_TIMESTAMP | JCAT_SIGN_FLAG_ADD_CERT,
-					    error);
-	if (jcat_blob == NULL)
+
+	/* add SHA256 checksum */
+	jcat_engine_csum = jcat_context_get_engine(jcat_context, JCAT_BLOB_KIND_SHA256, error);
+	if (jcat_engine_csum == NULL)
 		return FALSE;
-	jcat_item_add_blob(jcat_item, jcat_blob);
+	jcat_blob_csum =
+	    jcat_engine_self_sign(jcat_engine_csum, source_blob, JCAT_SIGN_FLAG_NONE, error);
+	if (jcat_blob_csum == NULL)
+		return FALSE;
+	jcat_item_add_blob(jcat_item, jcat_blob_csum);
+
+	/* sign using PKCS#7 */
+	jcat_engine_sig = jcat_context_get_engine(jcat_context, JCAT_BLOB_KIND_PKCS7, error);
+	if (jcat_engine_sig == NULL)
+		return FALSE;
+	jcat_blob_sig =
+	    jcat_engine_pubkey_sign(jcat_engine_sig,
+				    source_blob,
+				    cert,
+				    privkey,
+				    JCAT_SIGN_FLAG_ADD_TIMESTAMP | JCAT_SIGN_FLAG_ADD_CERT,
+				    error);
+	if (jcat_blob_sig == NULL)
+		return FALSE;
+	jcat_item_add_blob(jcat_item, jcat_blob_sig);
 	return TRUE;
 }
 
@@ -734,6 +781,7 @@ fu_cabinet_sign_enumerate_metainfo(FuCabinet *self, GPtrArray *files, GError **e
 			g_ptr_array_add(files, g_strdup("firmware.metainfo.xml"));
 		} else {
 			g_propagate_error(error, g_steal_pointer(&error_local));
+			fwupd_error_convert(error);
 			return FALSE;
 		}
 	} else {
@@ -770,6 +818,7 @@ fu_cabinet_sign_enumerate_firmware(FuCabinet *self, GPtrArray *files, GError **e
 			g_ptr_array_add(files, g_strdup("firmware.bin"));
 		} else {
 			g_propagate_error(error, g_steal_pointer(&error_local));
+			fwupd_error_convert(error);
 			return FALSE;
 		}
 	} else {
@@ -810,7 +859,6 @@ fu_cabinet_sign(FuCabinet *self,
 	g_autoptr(GOutputStream) ostr = NULL;
 	g_autoptr(GPtrArray) filenames = g_ptr_array_new_with_free_func(g_free);
 	g_autoptr(JcatContext) jcat_context = jcat_context_new();
-	g_autoptr(JcatEngine) jcat_engine = NULL;
 	g_autoptr(JcatFile) jcat_file = jcat_file_new();
 
 	g_return_val_if_fail(FU_IS_CABINET(self), FALSE);
@@ -835,14 +883,11 @@ fu_cabinet_sign(FuCabinet *self,
 		return FALSE;
 
 	/* sign all the files */
-	jcat_engine = jcat_context_get_engine(jcat_context, JCAT_BLOB_KIND_PKCS7, error);
-	if (jcat_engine == NULL)
-		return FALSE;
 	for (guint i = 0; i < filenames->len; i++) {
 		const gchar *filename = g_ptr_array_index(filenames, i);
 		if (!fu_cabinet_sign_filename(self,
 					      filename,
-					      jcat_engine,
+					      jcat_context,
 					      jcat_file,
 					      cert,
 					      privkey,
@@ -862,7 +907,7 @@ fu_cabinet_sign(FuCabinet *self,
 static gboolean
 fu_cabinet_parse(FuFirmware *firmware,
 		 GInputStream *stream,
-		 FwupdInstallFlags flags,
+		 FuFirmwareParseFlags flags,
 		 GError **error)
 {
 	FuCabinet *self = FU_CABINET(firmware);
@@ -877,6 +922,16 @@ fu_cabinet_parse(FuFirmware *firmware,
 
 	/* decompress and calculate container hashes */
 	if (stream != NULL) {
+		if ((flags & FU_FIRMWARE_PARSE_FLAG_CACHE_STREAM) == 0 &&
+		    (flags & FU_FIRMWARE_PARSE_FLAG_CACHE_BLOB) == 0) {
+			g_set_error_literal(
+			    error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_INVALID_FILE,
+			    "FuCabinet requires FU_FIRMWARE_PARSE_FLAG_CACHE_STREAM or "
+			    "FU_FIRMWARE_PARSE_FLAG_CACHE_BLOB for accurate checksums");
+			return FALSE;
+		}
 		if (!FU_FIRMWARE_CLASS(fu_cabinet_parent_class)
 			 ->parse(firmware, stream, flags, error))
 			return FALSE;
@@ -966,20 +1021,26 @@ XbNode *
 fu_cabinet_get_component(FuCabinet *self, const gchar *id, GError **error)
 {
 	g_autofree gchar *xpath = NULL;
+	g_autoptr(XbNode) xn = NULL;
 
 	g_return_val_if_fail(FU_IS_CABINET(self), NULL);
 	g_return_val_if_fail(id != NULL, NULL);
 	g_return_val_if_fail(error == NULL || *error == NULL, NULL);
 
 	xpath = g_strdup_printf("components/component/id[text()='%s']/..", id);
-	return xb_silo_query_first(self->silo, xpath, error);
+	xn = xb_silo_query_first(self->silo, xpath, error);
+	if (xn == NULL) {
+		fwupd_error_convert(error);
+		return NULL;
+	}
+	return g_steal_pointer(&xn);
 }
 
 static void
 fu_cabinet_init(FuCabinet *self)
 {
 	fu_cab_firmware_set_only_basename(FU_CAB_FIRMWARE(self), TRUE);
-	fu_firmware_set_size_max(FU_FIRMWARE(self), 1024 * 1024 * 100);
+	fu_firmware_set_size_max(FU_FIRMWARE(self), G_MAXUINT32); /* ~4GB */
 	self->builder = xb_builder_new();
 	self->jcat_file = jcat_file_new();
 	self->jcat_context = jcat_context_new();
