@@ -29,6 +29,7 @@ struct _FuRelease {
 	GInputStream *stream;
 	gchar *update_request_id;
 	gchar *device_version_old;
+	gchar *firmware_basename;
 	GPtrArray *soft_reqs; /* nullable, element-type XbNode */
 	GPtrArray *hard_reqs; /* nullable, element-type XbNode */
 	guint64 priority;
@@ -56,6 +57,7 @@ fu_release_to_string(FuRelease *self)
 	if (self->device != NULL)
 		fwupd_codec_string_append(str, idt, "Device", fu_device_get_id(self->device));
 	fwupd_codec_string_append(str, idt, "DeviceVersionOld", self->device_version_old);
+	fwupd_codec_string_append(str, idt, "FirmwareBasename", self->firmware_basename);
 	if (self->remote != NULL)
 		fwupd_codec_string_append(str, idt, "Remote", fwupd_remote_get_id(self->remote));
 	fwupd_codec_string_append_bool(str, idt, "HasConfig", self->config != NULL);
@@ -113,6 +115,34 @@ fu_release_get_device_version_old(FuRelease *self)
 	return self->device_version_old;
 }
 
+/**
+ * fu_release_get_firmware_basename:
+ * @self: a #FuRelease
+ *
+ * Gets the name of the update binary, typically `firmware.bin`
+ *
+ * Returns: a string value, or %NULL if never set.
+ **/
+const gchar *
+fu_release_get_firmware_basename(FuRelease *self)
+{
+	g_return_val_if_fail(FU_IS_RELEASE(self), NULL);
+	return self->firmware_basename;
+}
+
+void
+fu_release_set_firmware_basename(FuRelease *self, const gchar *firmware_basename)
+{
+	g_return_if_fail(FU_IS_RELEASE(self));
+
+	/* not changed */
+	if (g_strcmp0(self->firmware_basename, firmware_basename) == 0)
+		return;
+
+	g_free(self->firmware_basename);
+	self->firmware_basename = g_strdup(firmware_basename);
+}
+
 static void
 fu_release_set_device_version_old(FuRelease *self, const gchar *device_version_old)
 {
@@ -137,6 +167,10 @@ void
 fu_release_set_device(FuRelease *self, FuDevice *device)
 {
 	g_return_if_fail(FU_IS_RELEASE(self));
+
+	/* make tests easier */
+	fu_device_convert_instance_ids(device);
+
 	g_set_object(&self->device, device);
 	fu_release_set_device_version_old(self, fu_device_get_version(device));
 }
@@ -171,6 +205,15 @@ fu_release_get_stream(FuRelease *self)
 	return self->stream;
 }
 
+/* private: for tests */
+void
+fu_release_set_stream(FuRelease *self, GInputStream *stream)
+{
+	g_return_if_fail(FU_IS_RELEASE(self));
+	g_return_if_fail(G_IS_INPUT_STREAM(stream));
+	g_set_object(&self->stream, stream);
+}
+
 /**
  * fu_release_get_soft_reqs:
  * @self: a #FuRelease
@@ -401,7 +444,7 @@ fu_release_load_artifact(FuRelease *self, XbNode *artifact, GError **error)
 		return TRUE;
 	}
 	if (filename != NULL)
-		fwupd_release_set_filename(FWUPD_RELEASE(self), filename);
+		fu_release_set_filename(self, filename);
 
 	/* location */
 	locations = xb_node_query(artifact, "location", 0, NULL);
@@ -515,6 +558,15 @@ fu_release_verfmts_to_string(GPtrArray *verfmts)
 	return g_string_free(str, FALSE);
 }
 
+static gboolean
+fu_release_check_verfmt_compatible(FuRelease *self, FwupdVersionFormat fmt_rel)
+{
+	FwupdVersionFormat fmt_dev = fu_device_get_version_format(self->device);
+	if (fmt_dev == FWUPD_VERSION_FORMAT_BCD && fmt_rel == FWUPD_VERSION_FORMAT_PAIR)
+		return TRUE;
+	return fmt_dev == fmt_rel;
+}
+
 static gboolean
 fu_release_check_verfmt(FuRelease *self,
 			GPtrArray *verfmts,
@@ -540,7 +592,7 @@ fu_release_check_verfmt(FuRelease *self,
 		XbNode *verfmt = g_ptr_array_index(verfmts, i);
 		const gchar *tmp = xb_node_get_text(verfmt);
 		FwupdVersionFormat fmt_rel = fwupd_version_format_from_string(tmp);
-		if (fmt_dev == fmt_rel)
+		if (fu_release_check_verfmt_compatible(self, fmt_rel))
 			return TRUE;
 	}
 	verfmts_str = fu_release_verfmts_to_string(verfmts);
@@ -564,20 +616,15 @@ fu_release_check_verfmt(FuRelease *self,
 static gboolean
 fu_release_check_requirements(FuRelease *self,
 			      XbNode *component,
-			      XbNode *rel,
 			      FwupdInstallFlags install_flags,
 			      GError **error)
 {
 	const gchar *branch_new;
 	const gchar *branch_old;
 	const gchar *protocol;
-	const gchar *version;
-	const gchar *version_lowest;
 	gboolean matches_guid = FALSE;
-	gint vercmp;
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GPtrArray) provides = NULL;
-	g_autoptr(GPtrArray) verfmts = NULL;
 
 	/* does this component provide a GUID the device has */
 	provides = xb_node_query(component, "provides/firmware[@type='flashed']", 0, &error_local);
@@ -607,7 +654,8 @@ fu_release_check_requirements(FuRelease *self,
 	/* device requires a version check */
 	if (fu_device_has_flag(self->device, FWUPD_DEVICE_FLAG_VERSION_CHECK_REQUIRED)) {
 		if (!fu_release_check_requirements_version_check(self, error)) {
-			g_prefix_error(error, "device requires firmware with a version check: ");
+			g_prefix_error_literal(error,
+					       "device requires firmware with a version check: ");
 			return FALSE;
 		}
 	}
@@ -673,7 +721,45 @@ fu_release_check_requirements(FuRelease *self,
 		return FALSE;
 	}
 
-	/* get device */
+	/* success */
+	return TRUE;
+}
+
+/**
+ * fu_release_check_version:
+ * @self: a #FuRelease
+ * @component: (not nullable): a #XbNode
+ * @install_flags: a #FwupdInstallFlags, e.g. %FWUPD_INSTALL_FLAG_FORCE
+ * @error: (nullable): optional return location for an error
+ *
+ * Checks the component against this release, specifically that the device can be upgraded with this
+ * new firmware version.
+ *
+ * Returns: %TRUE if the requirements passed
+ **/
+gboolean
+fu_release_check_version(FuRelease *self,
+			 XbNode *component,
+			 FwupdInstallFlags install_flags,
+			 GError **error)
+{
+	const gchar *version;
+	const gchar *version_lowest;
+	gint vercmp;
+
+	g_return_val_if_fail(FU_IS_RELEASE(self), FALSE);
+	g_return_val_if_fail(XB_IS_NODE(component), FALSE);
+	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
+
+	/* skip */
+	if (self->device == NULL)
+		return TRUE;
+	if (self->request != NULL &&
+	    fu_engine_request_has_flag(self->request, FU_ENGINE_REQUEST_FLAG_NO_REQUIREMENTS)) {
+		return TRUE;
+	}
+
+	/* ensure device has a version */
 	version = fu_device_get_version(self->device);
 	if (version == NULL) {
 		g_set_error(error,
@@ -688,7 +774,7 @@ fu_release_check_requirements(FuRelease *self,
 	/* check the version formats match if set in the release */
 	if ((install_flags & FWUPD_INSTALL_FLAG_FORCE) == 0 &&
 	    (install_flags & FWUPD_INSTALL_FLAG_ALLOW_BRANCH_SWITCH) == 0) {
-		verfmts =
+		g_autoptr(GPtrArray) verfmts =
 		    xb_node_query(component, "custom/value[@key='LVFS::VersionFormat']", 0, NULL);
 		if (verfmts != NULL) {
 			if (!fu_release_check_verfmt(self, verfmts, install_flags, error))
@@ -719,10 +805,10 @@ fu_release_check_requirements(FuRelease *self,
 				    fu_device_get_version_format(self->device));
 	if (fu_device_has_flag(self->device, FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE) &&
 	    vercmp > 0) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOT_SUPPORTED,
-			    "Device only supports version upgrades");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "Device only supports version upgrades");
 		return FALSE;
 	}
 	if (vercmp == 0 && (install_flags & FWUPD_INSTALL_FLAG_ALLOW_REINSTALL) == 0) {
@@ -765,35 +851,6 @@ fu_release_get_priority(FuRelease *self)
 	return self->priority;
 }
 
-static void
-fu_release_ensure_device_by_checksum(FuRelease *self, XbNode *component, XbNode *rel)
-{
-	g_autoptr(GPtrArray) device_checksums = NULL;
-
-	/* sanity check */
-	if (fu_device_get_checksums(self->device)->len == 0)
-		return;
-	device_checksums = xb_node_query(rel, "checksum[@target='device']", 0, NULL);
-	if (device_checksums == NULL)
-		return;
-	for (guint i = 0; i < device_checksums->len; i++) {
-		XbNode *device_checksum = g_ptr_array_index(device_checksums, i);
-		if (!fu_device_has_checksum(self->device, xb_node_get_text(device_checksum)))
-			continue;
-		fu_device_ensure_from_component(self->device, component);
-		if (fu_device_has_private_flag(self->device,
-					       FU_DEVICE_PRIVATE_FLAG_MD_SET_VERSION)) {
-			const gchar *rel_version = xb_node_get_attr(rel, "version");
-			if (rel_version == NULL)
-				continue;
-			fu_device_set_version(self->device, rel_version);
-			fu_device_remove_private_flag(self->device,
-						      FU_DEVICE_PRIVATE_FLAG_MD_SET_VERSION);
-		}
-		break;
-	}
-}
-
 /**
  * fu_release_load:
  * @self: a #FuRelease
@@ -902,15 +959,6 @@ fu_release_load(FuRelease *self,
 	/* use the metadata to set the device attributes */
 	if (!fu_release_ensure_trust_flags(self, rel, error))
 		return FALSE;
-	if (self->device != NULL &&
-	    fu_release_has_flag(self, FWUPD_RELEASE_FLAG_TRUSTED_METADATA)) {
-		if (fu_device_has_private_flag(self->device,
-					       FU_DEVICE_PRIVATE_FLAG_MD_ONLY_CHECKSUM)) {
-			fu_release_ensure_device_by_checksum(self, component, rel);
-		} else {
-			fu_device_ensure_from_component(self->device, component);
-		}
-	}
 
 	/* per-release priority wins, but fallback to per-component priority */
 	tmp64 = xb_node_get_attr_as_uint(rel, "priority");
@@ -996,10 +1044,10 @@ fu_release_load(FuRelease *self,
 			fwupd_release_add_location(FWUPD_RELEASE(self), uri);
 		}
 	}
-	if (fwupd_release_get_filename(FWUPD_RELEASE(self)) == NULL) {
-		tmp = xb_node_query_text(rel, "checksum[@target='content']", NULL);
+	if (fu_release_get_filename(self) == NULL) {
+		tmp = xb_node_query_attr(rel, "checksum[@target='container']", "filename", NULL);
 		if (tmp != NULL)
-			fwupd_release_set_filename(FWUPD_RELEASE(self), tmp);
+			fu_release_set_filename(self, tmp);
 	}
 	tmp = xb_node_query_text(rel, "url[@type='details']", NULL);
 	if (tmp != NULL)
@@ -1007,6 +1055,9 @@ fu_release_load(FuRelease *self,
 	tmp = xb_node_query_text(rel, "url[@type='source']", NULL);
 	if (tmp != NULL)
 		fwupd_release_set_source_url(FWUPD_RELEASE(self), tmp);
+	tmp = xb_node_query_text(rel, "url[@type='sbom']", NULL);
+	if (tmp != NULL)
+		fwupd_release_set_sbom_url(FWUPD_RELEASE(self), tmp);
 	if (fwupd_release_get_checksums(FWUPD_RELEASE(self))->len == 0) {
 		g_autoptr(GPtrArray) checksums = NULL;
 		checksums = xb_node_query(rel, "checksum[@target='container']", 0, NULL);
@@ -1106,6 +1157,7 @@ fu_release_load(FuRelease *self,
 		if (!g_error_matches(error_hard, G_IO_ERROR, G_IO_ERROR_NOT_FOUND) &&
 		    !g_error_matches(error_hard, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT)) {
 			g_propagate_error(error, g_steal_pointer(&error_hard));
+			fwupd_error_convert(error);
 			return FALSE;
 		}
 	}
@@ -1114,6 +1166,7 @@ fu_release_load(FuRelease *self,
 		if (!g_error_matches(error_soft, G_IO_ERROR, G_IO_ERROR_NOT_FOUND) &&
 		    !g_error_matches(error_soft, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT)) {
 			g_propagate_error(error, g_steal_pointer(&error_soft));
+			fwupd_error_convert(error);
 			return FALSE;
 		}
 	}
@@ -1121,11 +1174,14 @@ fu_release_load(FuRelease *self,
 	/* get per-release firmware stream */
 	blob_basename = xb_node_get_data(rel, "fwupd::FirmwareBasename");
 	if (cabinet != NULL && blob_basename != NULL) {
-		const gchar *basename = (const gchar *)g_bytes_get_data(blob_basename, NULL);
 		g_autoptr(FuFirmware) img = NULL;
-		img = fu_firmware_get_image_by_id(FU_FIRMWARE(cabinet), basename, error);
+
+		self->firmware_basename = fu_strsafe_bytes(blob_basename, G_MAXSIZE);
+		img = fu_firmware_get_image_by_id(FU_FIRMWARE(cabinet),
+						  self->firmware_basename,
+						  error);
 		if (img == NULL) {
-			g_prefix_error(error, "failed to find %s: ", basename);
+			g_prefix_error(error, "failed to find %s: ", self->firmware_basename);
 			return FALSE;
 		}
 		self->stream = fu_firmware_get_stream(img, error);
@@ -1153,7 +1209,7 @@ fu_release_load(FuRelease *self,
 	/* check requirements for device */
 	if (self->device != NULL && self->request != NULL &&
 	    !fu_engine_request_has_flag(self->request, FU_ENGINE_REQUEST_FLAG_NO_REQUIREMENTS)) {
-		if (!fu_release_check_requirements(self, component, rel, install_flags, error))
+		if (!fu_release_check_requirements(self, component, install_flags, error))
 			return FALSE;
 	}
 
@@ -1305,6 +1361,7 @@ fu_release_finalize(GObject *obj)
 
 	g_free(self->update_request_id);
 	g_free(self->device_version_old);
+	g_free(self->firmware_basename);
 	if (self->request != NULL)
 		g_object_unref(self->request);
 	if (self->device != NULL)
