@@ -16,7 +16,6 @@
 #include <sys/socket.h>
 
 #include "fu-context-private.h"
-#include "fu-device-private.h"
 #include "fu-engine-struct.h"
 #include "fu-udev-backend.h"
 #include "fu-udev-device-private.h"
@@ -24,16 +23,54 @@
 struct _FuUdevBackend {
 	FuBackend parent_instance;
 	gint netlink_fd;
-	GHashTable *map_paths;	  /* of str:None */
-	GPtrArray *dpaux_devices; /* of FuDpauxDevice */
+	GHashTable *map_paths;	    /* of str:None */
+	GHashTable *coldplug_cache; /* of str:FuUdevBackendColdplugCacheItem */
+	GPtrArray *dpaux_devices;   /* of FuDpauxDevice */
 	guint dpaux_devices_rescan_id;
 	gboolean done_coldplug;
 };
 
+typedef struct {
+	FuUdevDevice *udev_device;
+	GError *error;
+} FuUdevBackendColdplugCacheItem;
+
 G_DEFINE_TYPE(FuUdevBackend, fu_udev_backend, FU_TYPE_BACKEND)
 
 #define FU_UDEV_BACKEND_DPAUX_RESCAN_DELAY 5 /* s */
 
+static void
+fu_udev_backend_coldplug_cache_item_free(FuUdevBackendColdplugCacheItem *item)
+{
+	if (item->udev_device != NULL)
+		g_object_unref(item->udev_device);
+	if (item->error)
+		g_error_free(item->error);
+	g_free(item);
+}
+
+static void
+fu_udev_backend_coldplug_cache_add_device(FuUdevBackend *self,
+					  const gchar *fn,
+					  FuUdevDevice *udev_device)
+{
+	if (!self->done_coldplug) {
+		FuUdevBackendColdplugCacheItem *item = g_new0(FuUdevBackendColdplugCacheItem, 1);
+		item->udev_device = g_object_ref(udev_device);
+		g_hash_table_insert(self->coldplug_cache, g_strdup(fn), item);
+	}
+}
+
+static void
+fu_udev_backend_coldplug_cache_add_error(FuUdevBackend *self, const gchar *fn, GError *error)
+{
+	if (!self->done_coldplug) {
+		FuUdevBackendColdplugCacheItem *item = g_new0(FuUdevBackendColdplugCacheItem, 1);
+		item->error = g_error_copy(error);
+		g_hash_table_insert(self->coldplug_cache, g_strdup(fn), item);
+	}
+}
+
 static void
 fu_udev_backend_to_string(FuBackend *backend, guint idt, GString *str)
 {
@@ -189,7 +226,7 @@ fu_udev_backend_create_device_for_donor(FuBackend *backend, FuDevice *donor, GEr
 		device = g_object_new(gtype, "backend", FU_BACKEND(self), NULL);
 		fu_device_incorporate(device, donor, FU_DEVICE_INCORPORATE_FLAG_ALL);
 		if (!fu_device_probe(device, error)) {
-			g_prefix_error(error, "failed to probe: ");
+			g_prefix_error_literal(error, "failed to probe: ");
 			return NULL;
 		}
 	}
@@ -228,16 +265,43 @@ static FuUdevDevice *
 fu_udev_backend_create_device(FuUdevBackend *self, const gchar *fn, GError **error)
 {
 	FuContext *ctx = fu_backend_get_context(FU_BACKEND(self));
-	g_autoptr(FuUdevDevice) device_donor = fu_udev_device_new(ctx, fn);
+	g_autoptr(FuDevice) device = NULL;
+	g_autoptr(FuUdevDevice) device_donor = NULL;
+	g_autoptr(GError) error_local = NULL;
+
+	/* query the cache to avoid scanning parent devices multiple times */
+	if (!self->done_coldplug) {
+		FuUdevBackendColdplugCacheItem *item =
+		    g_hash_table_lookup(self->coldplug_cache, fn);
+		if (item != NULL) {
+			if (item->udev_device == NULL) {
+				if (error != NULL)
+					*error = g_error_copy(item->error);
+				return NULL;
+			}
+			return g_object_ref(item->udev_device);
+		}
+	}
 
 	/* use a donor device to probe for the subsystem and devtype */
-	if (!fu_device_probe(FU_DEVICE(device_donor), error)) {
-		g_prefix_error(error, "failed to probe donor: ");
+	device_donor = fu_udev_device_new(ctx, fn);
+	if (!fu_device_probe(FU_DEVICE(device_donor), &error_local)) {
+		fu_udev_backend_coldplug_cache_add_error(self, fn, error_local);
+		g_propagate_prefixed_error(error,
+					   g_steal_pointer(&error_local),
+					   "failed to probe donor: ");
 		return NULL;
 	}
-	return FU_UDEV_DEVICE(fu_udev_backend_create_device_for_donor(FU_BACKEND(self),
-								      FU_DEVICE(device_donor),
-								      error));
+	device = fu_udev_backend_create_device_for_donor(FU_BACKEND(self),
+							 FU_DEVICE(device_donor),
+							 &error_local);
+	if (device == NULL) {
+		fu_udev_backend_coldplug_cache_add_error(self, fn, error_local);
+		g_propagate_error(error, g_steal_pointer(&error_local));
+		return NULL;
+	}
+	fu_udev_backend_coldplug_cache_add_device(self, fn, FU_UDEV_DEVICE(device));
+	return FU_UDEV_DEVICE(g_steal_pointer(&device));
 }
 
 static void
@@ -358,14 +422,17 @@ fu_udev_backend_coldplug_subsystem(FuUdevBackend *self, const gchar *fn)
 	}
 }
 
+/* if enabled, systemd takes the kernel event, runs the udev rules (which might rename devices)
+ * and then re-broadcasts on the udev netlink socket */
 static gboolean
 fu_udev_backend_netlink_parse_blob(FuUdevBackend *self, GBytes *blob, GError **error)
 {
-	FuContext *ctx = fu_backend_get_context(FU_BACKEND(self));
 	FuUdevAction action = FU_UDEV_ACTION_UNKNOWN;
+	g_autofree gchar *sysfsdir = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR);
+#ifdef HAVE_SYSTEMD
+	FuContext *ctx = fu_backend_get_context(FU_BACKEND(self));
 	const guint8 *buf;
 	gsize bufsz = 0;
-	g_autofree gchar *sysfsdir = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR);
 	g_autoptr(FuStructUdevMonitorNetlinkHeader) st_hdr = NULL;
 	g_autoptr(FuUdevDevice) device_donor = NULL;
 	g_autoptr(GBytes) blob_payload = NULL;
@@ -393,7 +460,7 @@ fu_udev_backend_netlink_parse_blob(FuUdevBackend *self, GBytes *blob, GError **e
 			g_set_error_literal(error,
 					    FWUPD_ERROR,
 					    FWUPD_ERROR_INTERNAL,
-					    "invalid ACSII buffer");
+					    "invalid ASCII buffer");
 			return FALSE;
 		}
 		kv = g_strsplit(kvstr, "=", 2);
@@ -461,7 +528,7 @@ fu_udev_backend_netlink_parse_blob(FuUdevBackend *self, GBytes *blob, GError **e
 		if (device_donor == NULL) {
 			g_set_error_literal(error,
 					    FWUPD_ERROR,
-					    FWUPD_ERROR_INVALID_DATA,
+					    FWUPD_ERROR_NOT_FOUND,
 					    "no device to change");
 			return FALSE;
 		}
@@ -488,6 +555,33 @@ fu_udev_backend_netlink_parse_blob(FuUdevBackend *self, GBytes *blob, GError **e
 		/* success */
 		fu_udev_backend_device_add_from_device(self, device_actual);
 	}
+#else
+	g_auto(GStrv) split = fu_strsplit_bytes(blob, "@", 2);
+
+	action = fu_udev_action_from_string(split[0]);
+	if (action == FU_UDEV_ACTION_ADD) {
+		g_autofree gchar *sysfspath = g_build_filename(sysfsdir, split[1], NULL);
+		g_autoptr(FuUdevDevice) device =
+		    fu_udev_backend_create_device(self, sysfspath, error);
+		if (device == NULL)
+			return FALSE;
+		fu_udev_backend_device_add_from_device(self, device);
+	} else if (action == FU_UDEV_ACTION_REMOVE) {
+		g_autofree gchar *sysfspath = g_build_filename(sysfsdir, split[1], NULL);
+		fu_udev_backend_device_remove(self, sysfspath);
+	} else if (action == FU_UDEV_ACTION_CHANGE) {
+		g_autofree gchar *sysfspath = g_build_filename(sysfsdir, split[1], NULL);
+		FuDevice *device_tmp = fu_backend_lookup_by_id(FU_BACKEND(self), sysfspath);
+		if (device_tmp == NULL) {
+			g_set_error_literal(error,
+					    FWUPD_ERROR,
+					    FWUPD_ERROR_INVALID_DATA,
+					    "no device to change");
+			return FALSE;
+		}
+		fu_backend_device_changed(FU_BACKEND(self), device_tmp);
+	}
+#endif
 
 	/* success */
 	return TRUE;
@@ -507,7 +601,8 @@ fu_udev_backend_netlink_cb(gint fd, GIOCondition condition, gpointer user_data)
 		return TRUE;
 	blob = g_bytes_new(buf, len);
 	if (!fu_udev_backend_netlink_parse_blob(self, blob, &error_local)) {
-		if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED)) {
+		if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED) ||
+		    g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND)) {
 			g_debug("ignoring netlink message: %s", error_local->message);
 			return TRUE;
 		}
@@ -523,7 +618,11 @@ fu_udev_backend_netlink_setup(FuUdevBackend *self, GError **error)
 	struct sockaddr_nl nls = {
 	    .nl_family = AF_NETLINK,
 	    .nl_pid = getpid(),
+#ifdef HAVE_SYSTEMD
 	    .nl_groups = FU_UDEV_MONITOR_NETLINK_GROUP_UDEV,
+#else
+	    .nl_groups = FU_UDEV_MONITOR_NETLINK_GROUP_KERNEL,
+#endif
 	};
 	g_autoptr(GSource) source = NULL;
 
@@ -601,6 +700,7 @@ fu_udev_backend_coldplug(FuBackend *backend, FuProgress *progress, GError **erro
 	}
 
 	/* success */
+	g_hash_table_remove_all(self->coldplug_cache);
 	self->done_coldplug = TRUE;
 	return TRUE;
 }
@@ -616,7 +716,7 @@ fu_udev_backend_setup(FuBackend *backend,
 	/* set up hotplug events */
 	if (flags & FU_BACKEND_SETUP_FLAG_USE_HOTPLUG) {
 		if (!fu_udev_backend_netlink_setup(self, error)) {
-			g_prefix_error(error, "failed to set up netlink: ");
+			g_prefix_error_literal(error, "failed to set up netlink: ");
 			return FALSE;
 		}
 	}
@@ -737,6 +837,7 @@ fu_udev_backend_finalize(GObject *object)
 	if (self->netlink_fd > 0)
 		g_close(self->netlink_fd, NULL);
 	g_hash_table_unref(self->map_paths);
+	g_hash_table_unref(self->coldplug_cache);
 	g_ptr_array_unref(self->dpaux_devices);
 	G_OBJECT_CLASS(fu_udev_backend_parent_class)->finalize(object);
 }
@@ -745,6 +846,11 @@ static void
 fu_udev_backend_init(FuUdevBackend *self)
 {
 	self->map_paths = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
+	self->coldplug_cache =
+	    g_hash_table_new_full(g_str_hash,
+				  g_str_equal,
+				  g_free,
+				  (GDestroyNotify)fu_udev_backend_coldplug_cache_item_free);
 	self->dpaux_devices = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 }
 
